@@ -55,7 +55,7 @@ class WXIMPEX MyExecPanel : public wxPanel, public MyProcessListener
 {
 public:
     // ctor(s)
-    MyExecPanel(wxWindow * parent);
+    explicit MyExecPanel(wxWindow * parent);
 
     void KillProcess();
 	void PauseProcess(bool pause = true);
@@ -164,6 +164,6 @@ private:
     DECLARE_EVENT_TABLE()
 };
 
-DECLARE_EVENT_TYPE(EVT_QUEUE_PROGRESS, -1)
+DECLARE_EXPORTED_EVENT_TYPE(WXIMPEX, EVT_QUEUE_PROGRESS, -1)
 
 #endif
