@@ -90,7 +90,7 @@ namespace HuginQueue
         /** generate the final argfile
             @return full name of generated argfile 
         */
-        wxString GenerateFinalArgfile(const HuginBase::Panorama & pano, const wxConfigBase* config, const HuginBase::UIntSet& images, const double exifToolVersion)
+        wxString GenerateFinalArgfile(const HuginBase::Panorama & pano, const wxString& projectName, const wxConfigBase* config, const HuginBase::UIntSet& images, const double exifToolVersion)
         {
             wxString argfileInput = config->Read(wxT("/output/FinalArgfile"), wxEmptyString);
             const bool generateGPanoTags = (config->Read(wxT("/output/writeGPano"), HUGIN_EXIFTOOL_CREATE_GPANO) == 1l) && (exifToolVersion >= 9.09);
@@ -119,6 +119,8 @@ namespace HuginQueue
             placeholders.insert(std::make_pair(wxT("%fullheight"), wxString::Format(wxT("%u"), opts.getHeight())));
             placeholders.insert(std::make_pair(wxT("%width"), wxString::Format(wxT("%d"), opts.getROI().width())));
             placeholders.insert(std::make_pair(wxT("%height"), wxString::Format(wxT("%d"), opts.getROI().height())));
+            wxFileName projectFilename(projectName);
+            placeholders.insert(std::make_pair(wxT("%projectname"), projectFilename.GetFullName()));
             // now open the final argfile
             wxFileName tempArgfileFinal(wxFileName::CreateTempFileName(GetConfigTempDir(config) + wxT("he")));
             wxFFileOutputStream outputStream(tempArgfileFinal.GetFullPath());
@@ -238,6 +240,7 @@ namespace HuginQueue
                         };
                         break;
                     case HuginBase::PanoramaOptions::INTERNAL_BLEND:
+                    default:  // switch to internal blender for all other cases, not exposed in GUI
                         output << _("Blender:") << wxT(" ") << _("internal") << wxEndl;
                         break;
                 };
@@ -427,6 +430,42 @@ namespace HuginQueue
             return new NormalCommand(command, finalArgs, comment);
 #endif
         }
+
+        /** build quoted filename list for verdandi */
+        wxString GetQuotedFilenamesStringForVerdandi(const wxArrayString& files, const HuginBase::Panorama& pano, const HuginBase::UIntSetVector& stacks, const int referenceImage, const bool hardSeam)
+        {
+            // if output is hard seam we keep the order
+            if (hardSeam)
+            {
+                return GetQuotedFilenamesString(files);
+            };
+            // user wants a blended seam, we need to figure out the correct order
+            int refImage = 0;
+            // first build a subpano which contains only one image per stack of the original pano
+            HuginBase::UIntSet stackImgs;
+            for (size_t i = 0; i < stacks.size(); ++i)
+            {
+                if (set_contains(stacks[i], referenceImage))
+                {
+                    refImage = i;
+                };
+                stackImgs.insert(*(stacks[i].begin()));
+            };
+            // now create the subpano, don't forget to delete at end
+            HuginBase::PanoramaData* subpano = pano.getNewSubset(stackImgs);
+            HuginBase::UIntSet subpanoImgs;
+            fill_set(subpanoImgs, 0, stackImgs.size() - 1);
+            // find the blend order
+            HuginBase::UIntVector blendOrder = HuginBase::getEstimatedBlendingOrder(*subpano, subpanoImgs, refImage);
+            delete subpano;
+            // now build the string in the correct order
+            wxString s;
+            for (size_t i = 0; i < blendOrder.size();++i)
+            {
+                s.Append(wxEscapeFilename(files[blendOrder[i]]) + wxT(" "));
+            };
+            return s;
+        };
     } // namespace detail
 
     CommandQueue* GetStitchingCommandQueue(const HuginBase::Panorama & pano, const wxString& ExePath, const wxString& project, const wxString& prefix, wxString& statusText, wxArrayString& outputFiles, wxArrayString& tempFilesDelete)
@@ -506,6 +545,7 @@ namespace HuginQueue
         wxString verdandiArgs;
         if (opts.blendMode == HuginBase::PanoramaOptions::INTERNAL_BLEND)
         {
+            verdandiArgs.Append(WXSTRING(opts.verdandiOptions));
             if ((opts.getHFOV() == 360.0) && (opts.getWidth() == opts.getROI().width()))
             {
                 verdandiArgs.Append(wxT(" -w"));
@@ -560,7 +600,7 @@ namespace HuginQueue
             wxFileName argfile(exiftoolArgfile);
             argfile.Normalize();
             exiftoolArgs.Append(wxT(" -@ ") + wxEscapeFilename(argfile.GetFullPath()) + wxT(" "));
-            wxString finalArgfile = detail::GenerateFinalArgfile(pano, config, allActiveImages, exiftoolVersion);
+            wxString finalArgfile = detail::GenerateFinalArgfile(pano, project, config, allActiveImages, exiftoolVersion);
             if (!finalArgfile.IsEmpty())
             {
                 exiftoolArgsFinal.Append(wxT(" -@ ") + wxEscapeFilename(finalArgfile) + wxT(" "));
@@ -582,6 +622,11 @@ namespace HuginQueue
                 {
                     finalNonaArgs.Append(wxT("-g "));
                 }
+                if (!opts.verdandiOptions.empty())
+                {
+                    finalNonaArgs.Append(WXSTRING(opts.verdandiOptions));
+                    finalNonaArgs.Append(wxT(" "));
+                };
                 if (opts.outputImageType == "tif")
                 {
                     finalNonaArgs.Append(wxT("-m TIFF "));
@@ -667,6 +712,11 @@ namespace HuginQueue
             {
                 // directly export exposure layers by nona
                 wxString finalNonaArgs(nonaArgs);
+                if (!opts.verdandiOptions.empty())
+                {
+                    finalNonaArgs.Append(WXSTRING(opts.verdandiOptions));
+                    finalNonaArgs.Append(wxT(" "));
+                };
                 finalNonaArgs.append(wxT("-r ldr --create-exposure-layers --ignore-exposure -o ") + wxEscapeFilename(prefix + wxT("_exposure_")));
                 if (opts.outputLDRExposureRemapped || opts.outputLDRStacks || opts.outputLDRExposureBlended)
                 {
@@ -714,19 +764,10 @@ namespace HuginQueue
                         const wxString exposureLayerImgName = wxString::Format(wxT("%s_exposure_%04u%s"), prefix.c_str(), exposureLayer, wxT(".tif"));
                         exposureLayersFiles.Add(exposureLayerImgName);
                         outputFiles.Add(exposureLayerImgName);
-                        switch (opts.blendMode)
-                        {
-                        case HuginBase::PanoramaOptions::ENBLEND_BLEND:
-                            commands->push_back(detail::GetEnblendFuseCommand(GetExternalProgram(config, ExePath, wxT("enblend")),
-                                enblendArgs + enLayersCompressionArgs + wxT(" -o ") + wxEscapeFilename(exposureLayerImgName) + wxT(" -- "),
-                                wxString::Format(_("Blending exposure layer %u..."), exposureLayer), exposureLayersImgs, tempFilesDelete));
-                            break;
-                        case HuginBase::PanoramaOptions::INTERNAL_BLEND:
-                            commands->push_back(new NormalCommand(GetInternalProgram(ExePath, wxT("verdandi")),
-                                verdandiArgs + enLayersCompressionArgs + wxT(" -o ") + wxEscapeFilename(exposureLayerImgName) + wxT(" -- ") + GetQuotedFilenamesString(exposureLayersImgs),
-                                wxString::Format(_("Blending exposure layer %u..."), exposureLayer)));
-                            break;
-                        }
+                        // variant with internal blender is handled before, so we need only enblend
+                        commands->push_back(detail::GetEnblendFuseCommand(GetExternalProgram(config, ExePath, wxT("enblend")),
+                            enblendArgs + enLayersCompressionArgs + wxT(" -o ") + wxEscapeFilename(exposureLayerImgName) + wxT(" -- "),
+                            wxString::Format(_("Blending exposure layer %u..."), exposureLayer), exposureLayersImgs, tempFilesDelete));
                         if (copyMetadata && opts.outputLDRExposureLayers)
                         {
                             filesForCopyTagsExiftool.Add(exposureLayerImgName);
@@ -789,10 +830,11 @@ namespace HuginQueue
                         };
                         break;
                     case HuginBase::PanoramaOptions::INTERNAL_BLEND:
+                    default:  // switch to internal blender for all other cases, not exposed in GUI
                         {
                             wxString finalVerdandiArgs(verdandiArgs + finalCompressionArgs);
                             finalVerdandiArgs.Append(wxT(" -o ") + wxEscapeFilename(fusedStacksFilename));
-                            finalVerdandiArgs.Append(wxT(" -- ") + GetQuotedFilenamesString(stackedImages));
+                            finalVerdandiArgs.Append(wxT(" -- ") + detail::GetQuotedFilenamesStringForVerdandi(stackedImages, pano, stacks, opts.colorReferenceImage, opts.verdandiOptions.find("--seam=blend") == std::string::npos));
                             commands->push_back(new NormalCommand(GetInternalProgram(ExePath, wxT("verdandi")),
                                 finalVerdandiArgs, _("Blending all stacks...")));
                         };
@@ -850,8 +892,9 @@ namespace HuginQueue
                                 enblendArgs + finalBlendArgs, _("Blending HDR stacks..."), stackedImages, tempFilesDelete));
                             break;
                         case HuginBase::PanoramaOptions::INTERNAL_BLEND:
+                        default:  // switch to internal blender for all other cases, not exposed in GUI
                             commands->push_back(new NormalCommand(GetInternalProgram(ExePath, wxT("verdandi")),
-                                verdandiArgs + finalBlendArgs + GetQuotedFilenamesString(stackedImages),
+                                verdandiArgs + finalBlendArgs + detail::GetQuotedFilenamesStringForVerdandi(stackedImages, pano, stacks, opts.colorReferenceImage, opts.verdandiOptions.find("--seam=blend") == std::string::npos),
                                 _("Blending HDR stacks...")));
                             break;
                     };
