@@ -257,6 +257,13 @@ bool wxAddImagesCmd::processPanorama(HuginBase::Panorama& pano)
     HuginBase::ImageVariableGroup & lenses = variable_groups.getLenses();
     const size_t oldImgCount = pano.getNrOfImages();
 
+    // read number of bands of first image
+    int panoBandCount = 0;
+    if (pano.getNrOfImages() > 0)
+    {
+        vigra::ImageImportInfo info(pano.getImage(0).getFilename().c_str());
+        panoBandCount = info.numBands() - info.numExtraBands();
+    };
     // load additional images...
     for (it = files.begin(); it != files.end(); ++it) {
         const std::string &filename = *it;
@@ -291,6 +298,27 @@ bool wxAddImagesCmd::processPanorama(HuginBase::Panorama& pano)
                     _("Warning"), wxOK | wxICON_EXCLAMATION);
                 continue;
             };
+            if (panoBandCount == 0)
+            {
+                panoBandCount = bands - extraBands;
+            };
+            if (panoBandCount != bands - extraBands)
+            {
+                wxString s(_("Hugin supports only grayscale or RGB images (without and with alpha channel)."));
+                s.Append(wxT("\n"));
+                if (panoBandCount == 3)
+                {
+                    s.Append(wxString::Format(_("File \"%s\" is a grayscale image, but other images in project are color images."), fname.c_str()));
+                }
+                else
+                {
+                    s.Append(wxString::Format(_("File \"%s\" is a color image, but other images in project are grayscale images."), fname.c_str()));
+                };
+                s.Append(wxT("\n"));
+                s.Append(_("Hugin does not support this mixing. Skipping this image.\nConvert this image to grayscale or RGB image and try loading again."));
+                wxMessageBox(s, _("Warning"), wxOK | wxICON_EXCLAMATION);
+                continue;
+            };
             if((pixelType=="UINT8") || (pixelType=="UINT16") || (pixelType=="INT16"))
                 srcImg.setResponseType(HuginBase::SrcPanoImage::RESPONSE_EMOR);
             else
@@ -831,6 +859,7 @@ bool wxNewProjectCmd::processPanorama(HuginBase::Panorama& pano)
     opts.blendMode = static_cast<HuginBase::PanoramaOptions::BlendingMechanism>(config->Read(wxT("/default_blender"), HUGIN_DEFAULT_BLENDER));
     opts.enblendOptions = config->Read(wxT("Enblend/Args"),wxT(HUGIN_ENBLEND_ARGS)).mb_str(wxConvLocal);
     opts.enfuseOptions = config->Read(wxT("Enfuse/Args"),wxT(HUGIN_ENFUSE_ARGS)).mb_str(wxConvLocal);
+    opts.verdandiOptions = config->Read(wxT("/VerdandiDefaultArgs"), wxEmptyString).mb_str(wxConvLocal);
     opts.interpolator = (vigra_ext::Interpolator)config->Read(wxT("Nona/Interpolator"),HUGIN_NONA_INTERPOLATOR);
     opts.remapUsingGPU = config->Read(wxT("Nona/useGPU"),HUGIN_NONA_USEGPU)!=0;
     opts.tiff_saveROI = config->Read(wxT("Nona/CroppedImages"),HUGIN_NONA_CROPPEDIMAGES)!=0;
