@@ -43,6 +43,7 @@
 #include "MeshManager.h"
 #include "ViewState.h"
 #include "GLRenderer.h"
+#include "GLViewer.h"
 #include "ToolHelper.h"
 #include <panodata/PanoramaOptions.h>
 
@@ -220,7 +221,7 @@ void GLPreviewRenderer::Redraw()
 
 void GLPanosphereOverviewRenderer::Redraw()
 {
-    glClearColor(0,0,0,0);
+    glClearColor(0,0,0,1);
 	glClear(GL_COLOR_BUFFER_BIT);
 
 	glMatrixMode(GL_MODELVIEW);
@@ -285,9 +286,9 @@ void GLPanosphereOverviewRenderer::Redraw()
     //event called only before drawing of the images with front faces culled (the inner face of the panosphere)
     static_cast<PanosphereOverviewToolHelper*>(m_tool_helper)->BeforeDrawImagesBack();
     //generic draw before images are drawn (called twice with front and back faces culled)
+    m_tex_man->Begin();
     m_tool_helper->BeforeDrawImages();
 
-    m_tex_man->Begin();
     // The old preview shows the lowest numbered image on top, so do the same:
     for (int img = imgs - 1; img != -1; img--)
     {
@@ -307,6 +308,7 @@ void GLPanosphereOverviewRenderer::Redraw()
         }
     }
 
+    m_tex_man->End();
     m_tool_helper->AfterDrawImages();
     m_tex_man->DisableTexture();
     static_cast<PanosphereOverviewToolHelper*>(m_tool_helper)->AfterDrawImagesBack();
@@ -336,6 +338,9 @@ void GLPanosphereOverviewRenderer::Redraw()
     glCullFace(GL_FRONT);
 
     static_cast<PanosphereOverviewToolHelper*>(m_tool_helper)->BeforeDrawImagesFront();
+
+    glEnable(GL_TEXTURE_2D);
+    m_tex_man->Begin();
     m_tool_helper->BeforeDrawImages();
 
     // The old preview shows the lowest numbered image on top, so do the same:
@@ -362,7 +367,7 @@ void GLPanosphereOverviewRenderer::Redraw()
     m_tool_helper->AfterDrawImages();
     m_tex_man->DisableTexture();
     static_cast<PanosphereOverviewToolHelper*>(m_tool_helper)->AfterDrawImagesFront();
-    
+
     m_tex_man->DisableTexture();
 
     glDisable(GL_CULL_FACE);
@@ -406,6 +411,7 @@ vigra::Diff2D GLPanosphereOverviewRenderer::Resize(int w, int h)
     //height of the screen in screen pixels over the length of the panosphere in panorama pixels when spread out
     double scrscale = (float) h  / (2 * tan(fovy / 360.0 * M_PI) * (R - radius) / (2 * radius * M_PI) * (options->getWidth()));
     m_visualization_state->SetScale(scrscale);
+    m_visualization_state->GetViewer()->MarkToolsDirty();
 //    DEBUG_DEBUG("renderer " << scrscale << " " << h << " " << R << " " << fovy);
 //    DEBUG_DEBUG("renderer scale " << scrscale);
 
@@ -488,11 +494,16 @@ void GLPlaneOverviewRenderer::Redraw()
         }
     }
 
-    m_tex_man->DisableTexture();
+    m_tex_man->End();
     m_tool_helper->AfterDrawImages();
 
+    m_tex_man->DisableTexture();
+
     glMatrixMode(GL_MODELVIEW);
     
+    glEnable(GL_TEXTURE_2D);
+    m_tex_man->Begin();
+
     m_tool_helper->BeforeDrawImages();
     // The old preview shows the lowest numbered image on top, so do the same:
     for (int img = imgs - 1; img != -1; img--)
@@ -514,9 +525,9 @@ void GLPlaneOverviewRenderer::Redraw()
     }
 
     m_tex_man->End();
-    m_tex_man->DisableTexture();
     // drawn things after the active image.
     m_tool_helper->AfterDrawImages();
+    m_tex_man->DisableTexture();
 
     glPopMatrix();
 }
@@ -556,7 +567,8 @@ vigra::Diff2D GLPlaneOverviewRenderer::Resize(int w, int h)
     double scrscale = (float) h / (2 * tan(fovy / 360.0 * M_PI) * R   * options->getWidth() / MeshManager::PlaneOverviewMeshInfo::scale);
     m_visualization_state->SetScale(scrscale);
 //    m_visualization_state->SetGLScale(gl_scale);
-	
+    m_visualization_state->GetViewer()->MarkToolsDirty();
+
     return vigra::Diff2D(0,0);
 }
 
