@@ -44,6 +44,7 @@
 
 bool GLViewer::initialised_glew=false;
 ViewState * GLViewer::m_view_state = NULL;
+size_t GLViewer::m_view_state_observer = 0;
 
 BEGIN_EVENT_TABLE(GLViewer, wxGLCanvas)
     EVT_PAINT (GLViewer::RedrawE)
@@ -97,6 +98,7 @@ GLViewer::GLViewer(
     
     started_creation = false;
     redrawing = false;
+    m_toolsInitialized = false;
 
     active = true;
 }
@@ -110,9 +112,11 @@ GLViewer::~GLViewer()
     {
       delete m_tool_helper;
       delete m_renderer;
+      delete m_visualization_state;
       // because m_view_state is a static member variable we need to check
       // if other class has already deleted it
-      if(m_view_state)
+      --m_view_state_observer;
+      if (m_view_state_observer == 0)
       {
         delete m_view_state;
         m_view_state=NULL;
@@ -165,18 +169,35 @@ void GLViewer::SetUpContext()
         }
 
         setUp();
+#ifdef __WXGTK__
+        if(this==frame->getPreview())
+        {
+            frame->getOverview()->setUp();
+        }
+        else
+        {
+            frame->getPreview()->setUp();
+        };
+#endif
     }
 }
 
 void GLPreview::setUp()
 {
     DEBUG_DEBUG("Preview Setup");
+    if (m_toolsInitialized)
+    {
+        return;
+    };
+    m_toolsInitialized = true;
     // we need something to store the state of the view and control updates
-    if (!m_view_state) {
+    if (!m_view_state)
+    {
         GLint countMultiTexture;
         glGetIntegerv(GL_MAX_TEXTURE_UNITS_ARB,&countMultiTexture);
         m_view_state = new ViewState(m_pano, countMultiTexture>1);
     }
+    ++m_view_state_observer;
     m_visualization_state = new VisualizationState(m_pano, m_view_state, this, RefreshWrapper, this, (PreviewMeshManager*) NULL);
     //Start the tools going:
     PreviewToolHelper *helper = new PreviewToolHelper(m_pano, m_visualization_state, frame);
@@ -188,15 +209,41 @@ void GLPreview::setUp()
                                  m_visualization_state, helper, m_background_color);
 }
 
+GLOverview::~GLOverview()
+{
+    if (m_renderer)
+    {
+        if (m_renderer == plane_m_renderer)
+        {
+            delete panosphere_m_tool_helper;
+            delete panosphere_m_renderer;
+            delete panosphere_m_visualization_state;
+        }
+        else
+        {
+            delete plane_m_tool_helper;
+            delete plane_m_renderer;
+            delete plane_m_visualization_state;
+        };
+    };
+}
+
 void GLOverview::setUp()
 {
-DEBUG_DEBUG("Overview Setup");
+    DEBUG_DEBUG("Overview Setup");
+    if (m_toolsInitialized)
+    {
+        return;
+    };
+    m_toolsInitialized = true;
     // we need something to store the state of the view and control updates
-    if (!m_view_state) {
+    if (!m_view_state)
+    {
         GLint countMultiTexture;
         glGetIntegerv(GL_MAX_TEXTURE_UNITS_ARB,&countMultiTexture);
         m_view_state = new ViewState(m_pano, countMultiTexture>1);
     }
+    ++m_view_state_observer;
 
     panosphere_m_visualization_state = new PanosphereOverviewVisualizationState(m_pano, m_view_state, this, RefreshWrapper, this);
     plane_m_visualization_state = new PlaneOverviewVisualizationState(m_pano, m_view_state, this, RefreshWrapper, this);
@@ -311,7 +358,7 @@ void GLViewer::Resized(wxSizeEvent& e)
    
     if (frame->CanResize()) {
         DEBUG_DEBUG("RESIZED_IN");
-#if !wxCHECK_VERSION(3,0,1)
+#if !wxCHECK_VERSION(3,0,0)
         wxGLCanvas::OnSize(e);
 #endif
         if(!IsShown()) return;
@@ -339,7 +386,11 @@ void GLViewer::Redraw()
     
     // we should use the window background colour outside the panorama
     // FIXME shouldn't this work on textured backrounds?
+#if defined __WXMAC__ && wxCHECK_VERSION(3,1,0) 
+    wxColour col(128,128,128);
+#else
     wxColour col = wxSystemSettings::GetColour(wxSYS_COLOUR_APPWORKSPACE);
+#endif
     m_renderer->SetBackground(col.Red(), col.Green(), col.Blue());
     if (m_visualization_state->RequireRecalculateViewport())
     {
@@ -417,6 +468,11 @@ void GLViewer::KeyUp(wxKeyEvent& e)
         m_tool_helper->KeypressEvent(e.GetKeyCode(), e.GetModifiers(), false);
 }
 
+void GLViewer::MarkToolsDirty()
+{
+    m_tool_helper->MarkDirty();
+}
+
 void GLViewer::SetViewerBackground(wxColour col)
 {
     this->m_background_color = col;
