@@ -70,6 +70,7 @@ public:
     
     VisualizationState * m_visualization_state;
     static ViewState * m_view_state;
+    static size_t m_view_state_observer;
 
     void SetActive(bool active) {this->active = active;}
     bool IsActive() {return active;}
@@ -79,7 +80,7 @@ public:
 #endif
 
     void SetViewerBackground(wxColour col);
-
+    void MarkToolsDirty();
 protected:
     void OnEraseBackground(wxEraseEvent& e);
     void MouseMotion(wxMouseEvent& e);
@@ -101,7 +102,7 @@ protected:
 
     virtual void setUp() = 0;
 
-    bool started_creation, redrawing;
+    bool started_creation, redrawing, m_toolsInitialized;
     static bool initialised_glew;
     vigra::Diff2D offset;
     GLPreviewFrame *frame;
@@ -138,6 +139,7 @@ public:
         panosphere_m_renderer = 0;
         plane_m_renderer = 0;
     }
+    ~GLOverview();
 
     void SetPanosphereMode();
     void SetPlaneMode();
