@@ -36,7 +36,7 @@
     wxDECLARE_EVENT(EVT_IMAGE_ADD,wxCommandEvent);
     wxDECLARE_EVENT(EVT_IMAGE_DEL,wxCommandEvent);
 #else
-#if _WINDOWS && defined Hugin_shared
+#if defined _WIN32 && defined Hugin_shared
     DECLARE_LOCAL_EVENT_TYPE(EVT_IMAGE_ADD,-1)
     DECLARE_LOCAL_EVENT_TYPE(EVT_IMAGE_DEL,-1)
 #else
