@@ -32,13 +32,10 @@
 
 #include "base_wx/platform.h"
 #include "base_wx/wxPlatform.h"
+#include "base_wx/wxcms.h"
 #include <vector>
 #include <map>
-#ifdef HAVE_CXX11
 #include <functional>    // std::bind
-#else
-#include <boost/bind.hpp>
-#endif
 
 #include "hugin/ImagesPanel.h"
 #include "base_wx/CommandHistory.h"
@@ -57,12 +54,6 @@
 
 #include <panodata/StandardImageVariableGroups.h>
 
-using namespace HuginBase;
-using namespace hugin_utils;
-using namespace vigra;
-using namespace vigra_ext;
-using namespace std;
-
 BEGIN_EVENT_TABLE(ImagesPanel, wxPanel)
     EVT_TREE_SEL_CHANGED(XRCID("images_tree_ctrl"), ImagesPanel::OnSelectionChanged )
     EVT_CHOICE     ( XRCID("images_lens_type"), ImagesPanel::OnLensTypeChanged)
@@ -112,7 +103,12 @@ bool ImagesPanel::Create(wxWindow *parent, wxWindowID id, const wxPoint& pos, co
     m_smallImgCtrl = XRCCTRL(*this, "images_selected_image", wxStaticBitmap);
     DEBUG_ASSERT(m_smallImgCtrl);
 
-    m_empty.Create(0,0);
+    // empty bitmap with size (0,0) is not valid for wxStaticBitmap
+    // so we create a bitmap with the background color of the static bitmap control
+    wxImage image(1, 1, true);
+    const wxColour imageBackgroundColor = m_smallImgCtrl->GetBackgroundColour();
+    image.SetRGB(0, 0, imageBackgroundColor.Red(), imageBackgroundColor.Green(), imageBackgroundColor.Blue());
+    m_empty = wxBitmap(image);
     m_smallImgCtrl->SetBitmap(m_empty);
 
     m_lenstype = XRCCTRL(*this, "images_lens_type", wxChoice);
@@ -163,7 +159,7 @@ bool ImagesPanel::Create(wxWindow *parent, wxWindowID id, const wxPoint& pos, co
     return true;
 }
 
-void ImagesPanel::Init(Panorama * panorama)
+void ImagesPanel::Init(HuginBase::Panorama * panorama)
 {
     m_pano = panorama;
     m_images_tree->Init(m_pano);
@@ -191,7 +187,6 @@ ImagesPanel::~ImagesPanel()
     m_maxEv->PopEventHandler(true);
     m_pano->removeObserver(this);
     wxChoice* group=XRCCTRL(*this,"images_group_mode", wxChoice);
-    size_t sel=group->GetSelection();
     DeleteClientData(group);
     DeleteClientData(m_optChoice);
     DeleteClientData(m_optPhotoChoice);
@@ -268,7 +263,7 @@ void ImagesPanel::panoramaImagesChanged(HuginBase::Panorama &pano, const HuginBa
     DEBUG_TRACE("");
 
     // update text field if selected
-    const UIntSet & selected = m_images_tree->GetSelectedImages();
+    const HuginBase::UIntSet & selected = m_images_tree->GetSelectedImages();
     DEBUG_DEBUG("nr of sel Images: " << selected.size());
     if (pano.getNrOfImages() == 0)
     {
@@ -291,21 +286,30 @@ void ImagesPanel::panoramaImagesChanged(HuginBase::Panorama &pano, const HuginBa
 /** run control point detector on selected images, and add control points */
 void ImagesPanel::CPGenerate(wxCommandEvent & e)
 {
-    UIntSet selImg = m_images_tree->GetSelectedImages();
+    HuginBase::UIntSet selImg = m_images_tree->GetSelectedImages();
     //if only one image is selected, run detector on all images, except for linefind
-    wxString progName=cpdetector_config.settings[m_CPDetectorChoice->GetSelection()].GetProg().Lower();
-    if ((selImg.size()==0) || (selImg.size()==1 && progName.Find(wxT("linefind"))==wxNOT_FOUND))
+    wxString progName = cpdetector_config.settings[m_CPDetectorChoice->GetSelection()].GetProg().Lower();
+    if ((selImg.size() == 0) || (selImg.size() == 1 && progName.Find(wxT("linefind")) == wxNOT_FOUND))
     {
         // add all images.
         selImg.clear();
-        fill_set(selImg,0,m_pano->getNrOfImages()-1);
+        fill_set(selImg, 0, m_pano->getNrOfImages() - 1);
     }
 
-    if (selImg.size() == 0)
+    if (selImg.empty())
     {
         return;
     }
+    RunCPGenerator(cpdetector_config.settings[m_CPDetectorChoice->GetSelection()], selImg);
+};
 
+void ImagesPanel::RunCPGenerator(const HuginBase::UIntSet& img)
+{
+    RunCPGenerator(cpdetector_config.settings[m_CPDetectorChoice->GetSelection()], img);
+}
+
+void ImagesPanel::RunCPGenerator(CPDetectorSetting &setting, const HuginBase::UIntSet& img)
+{
     wxConfigBase* config=wxConfigBase::Get();
     long nFeatures = HUGIN_ASS_NCONTROLPOINTS;
 #if wxCHECK_VERSION(2,9,4)
@@ -333,8 +337,7 @@ void ImagesPanel::CPGenerate(wxCommandEvent & e)
     };
 
     AutoCtrlPointCreator matcher;
-    HuginBase::CPVector cps = matcher.automatch(cpdetector_config.settings[m_CPDetectorChoice->GetSelection()],
-        *m_pano, selImg, nFeatures,this);
+    HuginBase::CPVector cps = matcher.automatch(setting, *m_pano, img, nFeatures, this);
     wxString msg;
     wxMessageBox(wxString::Format(_("Added %lu control points"), (unsigned long) cps.size()), _("Control point detector result"),wxOK|wxICON_INFORMATION,this);
     PanoCommand::GlobalCmdHist::getInstance().addCommand(
@@ -343,9 +346,14 @@ void ImagesPanel::CPGenerate(wxCommandEvent & e)
 
 };
 
+const wxString ImagesPanel::GetSelectedCPGenerator()
+{
+    return cpdetector_config.settings[m_CPDetectorChoice->GetSelection()].GetCPDetectorDesc();
+};
+
 void ImagesPanel::OnSelectionChanged(wxTreeEvent & e)
 {
-    const UIntSet & sel = m_images_tree->GetSelectedImages();
+    const HuginBase::UIntSet & sel = m_images_tree->GetSelectedImages();
     DEBUG_DEBUG("selected Images: " << sel.size());
     if (sel.size() == 0)
     {
@@ -356,20 +364,20 @@ void ImagesPanel::OnSelectionChanged(wxTreeEvent & e)
     {
         // enable edit
         EnableImageCtrls();
-        const SrcPanoImage& img=m_pano->getImage(*sel.begin());
+        const HuginBase::SrcPanoImage& img = m_pano->getImage(*sel.begin());
         bool identical_projection=true;
-        SrcPanoImage::Projection proj=img.getProjection();
-        double focallength=SrcPanoImage::calcFocalLength(img.getProjection(),img.getHFOV(),
+        HuginBase::SrcPanoImage::Projection proj = img.getProjection();
+        double focallength = HuginBase::SrcPanoImage::calcFocalLength(img.getProjection(), img.getHFOV(),
                 img.getCropFactor(),img.getSize());;
         double cropFactor=img.getCropFactor();
-        for(UIntSet::const_iterator it=sel.begin(); it!=sel.end(); ++it)
+        for (HuginBase::UIntSet::const_iterator it = sel.begin(); it != sel.end(); ++it)
         {
-            const SrcPanoImage& img2=m_pano->getImage(*it);
+            const HuginBase::SrcPanoImage& img2 = m_pano->getImage(*it);
             if(proj!=img2.getProjection())
             {
                 identical_projection=false;
             };
-            double focallength2 = SrcPanoImage::calcFocalLength(img2.getProjection(),img2.getHFOV(),
+            double focallength2 = HuginBase::SrcPanoImage::calcFocalLength(img2.getProjection(), img2.getHFOV(),
                 img2.getCropFactor(),img2.getSize());
             if(focallength>0 && fabs(focallength-focallength2)>0.05)
             {
@@ -399,7 +407,7 @@ void ImagesPanel::OnSelectionChanged(wxTreeEvent & e)
         };
         if(cropFactor>0)
         {
-            m_cropfactor->SetValue(doubleTowxString(cropFactor,m_degDigits));
+            m_cropfactor->SetValue(hugin_utils::doubleTowxString(cropFactor,m_degDigits));
         }
         else
         {
@@ -462,11 +470,7 @@ void ImagesPanel::UpdatePreviewImage()
                 m_pano->getImage(m_showImgNr).getFilename());
         // When the image is ready, try this function again.
         thumbnail_request->ready.push_back(
-#ifdef HAVE_CXX11
             std::bind(&ImagesPanel::UpdatePreviewImage, this)
-#else
-            boost::bind(&ImagesPanel::UpdatePreviewImage, this)
-#endif
             );
     } else {
         // forget any request now the image has loaded.
@@ -491,6 +495,11 @@ void ImagesPanel::UpdatePreviewImage()
         // on a small window, m_smallImgCtrl can have 0 width.
         sz.IncTo(wxSize(1,1));
         wxImage scaled = img.Scale(sz.GetWidth(),sz.GetHeight());
+        // now apply color profile
+        if (!cacheEntry->iccProfile->empty() || huginApp::Get()->HasMonitorProfile())
+        {
+            HuginBase::Color::CorrectImage(scaled, *(cacheEntry->iccProfile), huginApp::Get()->GetMonitorProfile());
+        };
         m_smallImgCtrl->SetBitmap(wxBitmap(scaled));
         m_smallImgCtrl->GetParent()->Layout();
         m_smallImgCtrl->Refresh();
@@ -509,11 +518,11 @@ void ImagesPanel::ReloadCPDetectorSettings()
 void ImagesPanel::OnLensTypeChanged (wxCommandEvent & e)
 {
     size_t var = GetSelectedValue(m_lenstype);
-    UIntSet images=m_images_tree->GetSelectedImages();
+    HuginBase::UIntSet images = m_images_tree->GetSelectedImages();
     if(images.size()>0)
     {
-        const SrcPanoImage & img=m_pano->getImage(*(images.begin()));
-        double focal_length = SrcPanoImage::calcFocalLength(img.getProjection(),img.getHFOV(),img.getCropFactor(),img.getSize());
+        const HuginBase::SrcPanoImage & img = m_pano->getImage(*(images.begin()));
+        double focal_length = HuginBase::SrcPanoImage::calcFocalLength(img.getProjection(), img.getHFOV(), img.getCropFactor(), img.getSize());
         std::vector<PanoCommand::PanoCommand*> commands;
         commands.push_back(new PanoCommand::ChangeImageProjectionCmd(*m_pano, images,(HuginBase::SrcPanoImage::Projection) var));
         commands.push_back(new PanoCommand::UpdateFocalLengthCmd(*m_pano, images, focal_length));
@@ -536,7 +545,7 @@ void ImagesPanel::OnFocalLengthChanged(wxCommandEvent & e)
         return;
     };
     double val;
-    if (!str2double(text, val))
+    if (!hugin_utils::str2double(text, val))
     {
         return;
     }
@@ -547,9 +556,9 @@ void ImagesPanel::OnFocalLengthChanged(wxCommandEvent & e)
         return;
     };
     
-    UIntSet images=m_images_tree->GetSelectedImages();
-    const SrcPanoImage& srcImg=m_pano->getImage(*(images.begin()));
-    if(srcImg.getProjection()==SrcPanoImage::FISHEYE_ORTHOGRAPHIC)
+    HuginBase::UIntSet images = m_images_tree->GetSelectedImages();
+    const HuginBase::SrcPanoImage& srcImg = m_pano->getImage(*(images.begin()));
+    if (srcImg.getProjection() == HuginBase::SrcPanoImage::FISHEYE_ORTHOGRAPHIC)
     {
         double hfov=srcImg.calcHFOV(srcImg.getProjection(), val, srcImg.getCropFactor(), srcImg.getSize());
         if(hfov>190)
@@ -587,7 +596,7 @@ void ImagesPanel::OnCropFactorChanged(wxCommandEvent & e)
         return;
     };
     double val;
-    if (!str2double(text, val))
+    if (!hugin_utils::str2double(text, val))
     {
         return;
     }
@@ -598,7 +607,7 @@ void ImagesPanel::OnCropFactorChanged(wxCommandEvent & e)
         return;
     };
 
-    UIntSet images=m_images_tree->GetSelectedImages();
+    HuginBase::UIntSet images = m_images_tree->GetSelectedImages();
     PanoCommand::GlobalCmdHist::getInstance().addCommand(
         new PanoCommand::UpdateCropFactorCmd(*m_pano,images,val)
     );
@@ -612,14 +621,14 @@ void ImagesPanel::OnMinimumOverlapChanged(wxCommandEvent & e)
         return;
     };
     double val;
-    if (!str2double(text, val))
+    if (!hugin_utils::str2double(text, val))
     {
         return;
     }
     if(fabs(val)<0.001 || val>1)
     {
         wxMessageBox(_("The minimum overlap has to be greater than 0 and smaller than 1."),
-#ifdef _WINDOWS
+#ifdef _WIN32
             _("Hugin"),
 #else
             wxT(""),
@@ -646,14 +655,14 @@ void ImagesPanel::OnMaxEvDiffChanged(wxCommandEvent& e)
         return;
     };
     double val;
-    if (!str2double(text, val))
+    if (!hugin_utils::str2double(text, val))
     {
         return;
     }
     if(val<0)
     {
         wxMessageBox(_("The maximum Ev difference has to be greater than 0."),
-#ifdef _WINDOWS
+#ifdef _WIN32
             _("Hugin"),
 #else
             wxT(""),
