@@ -57,6 +57,7 @@
 #include "hugin/LocalizedFileTipProvider.h"
 #include "algorithms/control_points/CleanCP.h"
 #include "hugin/PanoOperation.h"
+#include "hugin/PapywizardImport.h"
 
 #include "base_wx/MyProgressDialog.h"
 #include "base_wx/RunStitchPanel.h"
@@ -203,6 +204,7 @@ BEGIN_EVENT_TABLE(MainFrame, wxFrame)
     EVT_MENU(XRCID("action_save_as_ptstitcher"),  MainFrame::OnSavePTStitcherAs)
     EVT_MENU(XRCID("action_open_batch_processor"),  MainFrame::OnOpenPTBatcher)
     EVT_MENU(XRCID("action_import_project"), MainFrame::OnMergeProject)
+    EVT_MENU(XRCID("action_import_papywizard"), MainFrame::OnReadPapywizard)
     EVT_MENU(XRCID("action_apply_template"),  MainFrame::OnApplyTemplate)
     EVT_MENU(XRCID("action_exit_hugin"),  MainFrame::OnUserQuit)
     EVT_MENU_RANGE(wxID_FILE1, wxID_FILE9, MainFrame::OnMRUFiles)
@@ -230,6 +232,7 @@ BEGIN_EVENT_TABLE(MainFrame, wxFrame)
     EVT_BUTTON(XRCID("ID_SHOW_GL_PREVIEW_FRAME"), MainFrame::OnToggleGLPreviewFrame)
 
     EVT_MENU(XRCID("action_optimize"),  MainFrame::OnOptimize)
+    EVT_MENU(XRCID("action_optimize_only_active"), MainFrame::OnOnlyActiveImages)
     EVT_BUTTON(XRCID("action_optimize"),  MainFrame::OnOptimize)
     EVT_MENU(XRCID("action_finetune_all_cp"), MainFrame::OnFineTuneAll)
 //    EVT_BUTTON(XRCID("action_finetune_all_cp"), MainFrame::OnFineTuneAll)
@@ -327,6 +330,7 @@ MainFrame::MainFrame(wxWindow* parent, HuginBase::Panorama & pano)
             dc.GetTextExtent(version, &tw, &th);
             // place text on bitmap.
             dc.DrawText(version, bitmap.GetWidth() - tw - 3, bitmap.GetHeight() - th - 3);
+            dc.SelectObject(wxNullBitmap);
         }
 
         splash = new HuginSplashScreen(NULL, bitmap);
@@ -358,6 +362,7 @@ MainFrame::MainFrame(wxWindow* parent, HuginBase::Panorama & pano)
     m_menu_file_advanced=wxXmlResource::Get()->LoadMenu(wxT("file_menu_advanced"));
     mainMenu->Insert(0, m_menu_file_simple, _("&File"));
     SetMenuBar(mainMenu);
+    SetOptimizeOnlyActiveImages(m_optOnlyActiveImages);
 
 #ifdef HUGIN_HSI
     wxMenuBar* menubar=GetMenuBar();
@@ -563,6 +568,7 @@ MainFrame::MainFrame(wxWindow* parent, HuginBase::Panorama & pano)
 #endif
 #endif
     //reload gui level
+    m_guiLevel=GUI_ADVANCED;
     long guiLevel=config->Read(wxT("/GuiLevel"),(long)0);
     guiLevel = std::max<long>(0, std::min<long>(2, guiLevel));
     if(guiLevel==GUI_SIMPLE && disableOpenGL)
@@ -1207,7 +1213,11 @@ void MainFrame::DisplayHelp(wxString section)
     }
     else
     {
+#if wxCHECK_VERSION(3,1,1)
+        GetHelpController().DisplaySection(section);
+#else
         GetHelpController().DisplayHelpPage(section);
+#endif
     };
 #else
     if (section.IsEmpty())
@@ -1382,6 +1392,31 @@ void MainFrame::OnOptimize(wxCommandEvent & e)
     opt_panel->OnOptimizeButton(dummy);
 }
 
+void MainFrame::OnOnlyActiveImages(wxCommandEvent &e)
+{
+    m_optOnlyActiveImages = GetMenuBar()->IsChecked(XRCID("action_optimize_only_active"));
+    opt_panel->SetOnlyActiveImages(m_optOnlyActiveImages);
+    // notify all observer so they can update their display
+    pano.changeFinished();
+};
+
+void MainFrame::SetOptimizeOnlyActiveImages(const bool onlyActive)
+{
+    m_optOnlyActiveImages = onlyActive;
+    wxMenuBar* menubar = GetMenuBar();
+    if (menubar)
+    {
+        menubar->Check(XRCID("action_optimize_only_active"), onlyActive);
+        // notify all observer so they can update their display
+        pano.changeFinished();
+    };
+};
+
+const bool MainFrame::GetOptimizeOnlyActiveImages() const
+{
+    return m_optOnlyActiveImages;
+};
+
 void MainFrame::OnPhotometricOptimize(wxCommandEvent & e)
 {
     wxCommandEvent dummy;
@@ -1446,6 +1481,20 @@ void MainFrame::OnMergeProject(wxCommandEvent & e)
     }
 }
 
+void MainFrame::OnReadPapywizard(wxCommandEvent & e)
+{
+    wxString currentDir = wxConfigBase::Get()->Read(wxT("/actualPath"), wxT(""));
+    wxFileDialog dlg(wxGetActiveWindow(), _("Open Papywizard xml file"),
+        currentDir, wxT(""), _("Papywizard xml files (*.xml)|*.xml|All files (*)|*"),
+        wxFD_OPEN, wxDefaultPosition);
+    dlg.SetDirectory(currentDir);
+    if (dlg.ShowModal() == wxID_OK)
+    {
+        wxConfigBase::Get()->Write(wxT("/actualPath"), dlg.GetDirectory());
+        Papywizard::ImportPapywizardFile(dlg.GetPath(), pano);
+    };
+};
+
 void MainFrame::OnApplyTemplate(wxCommandEvent & e)
 {
     // get the global config object
@@ -1768,18 +1817,21 @@ void MainFrame::enableTools(bool option)
     theMenuBar->Enable(XRCID("ID_SHOW_PREVIEW_FRAME"), option);
     theMenuBar->Enable(XRCID("action_stitch"), option);
     theMenuBar->Enable(XRCID("action_stitch_userdefined"), option);
+    m_menu_file_advanced->Enable(XRCID("action_import_papywizard"), option);
     //theMenuBar->Enable(XRCID("ID_SHOW_GL_PREVIEW_FRAME"), option);
 }
 
 
 void MainFrame::OnSize(wxSizeEvent &e)
 {
+#ifdef DEBUG
     wxSize sz = this->GetSize();
     wxSize csz = this->GetClientSize();
     wxSize vsz = this->GetVirtualSize();
     DEBUG_TRACE(" size:" << sz.x << "," << sz.y <<
                 " client: "<< csz.x << "," << csz.y <<
                 " virtual: "<< vsz.x << "," << vsz.y);
+#endif
 
     Layout();
     e.Skip();
