@@ -23,9 +23,6 @@
 #include <wx/wx.h>
 #include <wx/platform.h>
 
-#if !defined Hugin_shared || !defined _WINDOWS
-#define GLEW_STATIC
-#endif
 #include <GL/glew.h>
 
 #ifdef __WXMAC__
@@ -131,11 +128,11 @@ MeshManager::MeshInfo::MeshInfo(HuginBase::Panorama * m_pano_in,
     :   display_list_number(glGenLists(1)), // Find a free display list.
         image(*image),
         m_pano(m_pano_in),
+        scale_factor(3.0),
         m_visualization_state(visualization_state_in),
         remap(layout_mode_on_in ? (MeshRemapper *) new LayoutRemapper(m_pano, &(this->image), m_visualization_state)
                                 : (MeshRemapper *) new ChoosyRemapper(m_pano, &(this->image), m_visualization_state)),
-        layout_mode_on(layout_mode_on_in),
-        scale_factor(3.0)
+        layout_mode_on(layout_mode_on_in)
 {
 }
 
@@ -144,11 +141,11 @@ MeshManager::MeshInfo::MeshInfo(const MeshInfo & source)
     :   display_list_number(glGenLists(1)),
     image(source.image),
     m_pano(source.m_pano),
+    scale_factor(3.0),
     m_visualization_state(source.m_visualization_state),
     remap(source.layout_mode_on ? (MeshRemapper *) new LayoutRemapper(source.m_pano, (HuginBase::SrcPanoImage*) &(source.image), source.m_visualization_state)
                                 : (MeshRemapper *) new ChoosyRemapper(source.m_pano, (HuginBase::SrcPanoImage*) &(source.image), source.m_visualization_state)),
-    layout_mode_on(source.layout_mode_on),
-    scale_factor(3.0)
+    layout_mode_on(source.layout_mode_on)
 {
 }
 
@@ -227,7 +224,6 @@ void MeshManager::MeshInfo::CompileList()
         #endif
             // get each face's coordinates from the remapper
             MeshRemapper::Coords coords;
-            bool write = true;
             while (remap->GetNextFaceCoordinates(&coords))
             {
                 MeshCoords3D coords3d = m_visualization_state->GetMeshManager()->GetMeshCoords3D(coords);
@@ -335,7 +331,7 @@ MeshManager::MeshInfo::Coord3D MeshManager::PanosphereOverviewMeshInfo::GetCoord
 
     MeshManager::MeshInfo::Coord3D res;
 
-    double r = ((PanosphereOverviewVisualizationState*)state)->getSphereRadius();
+    double r = static_cast<PanosphereOverviewVisualizationState*>(state)->getSphereRadius();
     double th, ph;
     th = ((coord.x / width) * hfov - hfov / 2.0);
     ph = ((coord.y / height) * vfov - vfov / 2.0);
@@ -359,7 +355,7 @@ MeshManager::MeshInfo::MeshCoords3D MeshManager::PanosphereOverviewMeshInfo::Get
     hfov = 360;
     vfov = 180;
 
-    double r = ((PanosphereOverviewVisualizationState*)state)->getSphereRadius();
+    double r = static_cast<PanosphereOverviewVisualizationState*>(state)->getSphereRadius();
 
     MeshCoords3D res;
     for (int x = 0 ; x < 2 ; x++) {
