@@ -19,8 +19,8 @@
  *  Lesser General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -31,6 +31,8 @@
 #include "hugin/huginApp.h"
 #include "base_wx/platform.h"
 #include "hugin/config_defaults.h"
+#include "algorithms/basic/LayerStacks.h"
+#include "algorithms/basic/CalculateOptimalScale.h"
 
 BEGIN_EVENT_TABLE(PanoOutputDialog,wxDialog)
     EVT_BUTTON(wxID_OK, PanoOutputDialog::OnOk)
@@ -44,7 +46,7 @@ BEGIN_EVENT_TABLE(PanoOutputDialog,wxDialog)
     EVT_SPINCTRL(XRCID("output_height"), PanoOutputDialog::OnHeightChanged)
 END_EVENT_TABLE()
 
-PanoOutputDialog::PanoOutputDialog(wxWindow *parent, PT::Panorama& pano, GuiLevel guiLevel) : m_pano(pano), m_aspect(0)
+PanoOutputDialog::PanoOutputDialog(wxWindow *parent, HuginBase::Panorama& pano, GuiLevel guiLevel) : m_pano(pano), m_aspect(0)
 {
     // load our children. some children might need special
     // initialization. this will be done later.
@@ -75,8 +77,9 @@ PanoOutputDialog::PanoOutputDialog(wxWindow *parent, PT::Panorama& pano, GuiLeve
     m_stacks=getHDRStacks(m_pano, images, m_pano.getOptions());
     m_exposureLayers=getExposureLayers(m_pano, images, m_pano.getOptions());
     // set initial width
-    long opt_width=m_pano.calcOptimalWidth();
-    m_newOpt=m_pano.getOptions();
+    m_newOpt = m_pano.getOptions();
+    long opt_width = hugin_utils::roundi(HuginBase::CalculateOptimalScale::calcOptimalScale(m_pano) * m_newOpt.getWidth());
+
     double sizeFactor = HUGIN_ASS_PANO_DOWNSIZE_FACTOR;
     wxConfigBase* config = wxConfigBase::Get();
     config->Read(wxT("/Assistant/panoDownsizeFactor"), &sizeFactor, HUGIN_ASS_PANO_DOWNSIZE_FACTOR);
@@ -153,14 +156,14 @@ void PanoOutputDialog::EnableOutputOptions()
     {
         XRCCTRL(*this, "output_hdr", wxCheckBox)->SetValue(true);
         XRCCTRL(*this, "output_hdr", wxCheckBox)->Enable(true);
-        XRCCTRL(*this, "output_hdr_bitmap", wxCheckBox)->Enable(true);
+        XRCCTRL(*this, "output_hdr_bitmap", wxStaticBitmap)->Enable(true);
         return;
     }
     //hide hdr controls for simple interface
     if(m_guiLevel==GUI_SIMPLE)
     {
         XRCCTRL(*this, "output_hdr", wxCheckBox)->Hide();
-        XRCCTRL(*this, "output_hdr_bitmap", wxCheckBox)->Hide();
+        XRCCTRL(*this, "output_hdr_bitmap", wxStaticBitmap)->Hide();
         XRCCTRL(*this, "output_hdr_format_label", wxStaticText)->Hide();
         XRCCTRL(*this, "output_hdr_format", wxChoice)->Hide();
         XRCCTRL(*this, "output_hdr_compression_label", wxStaticText)->Hide();
@@ -169,24 +172,24 @@ void PanoOutputDialog::EnableOutputOptions()
         GetSizer()->Fit(this);
     };
     //single image or normal panorama, enable only normal output
-    if(m_pano.getNrOfImages()==1 || m_stacks.size() >= 0.8 * m_pano.getNrOfImages())
+    if(m_pano.getNrOfImages()==1 || m_stacks.size() >= 0.7 * m_pano.getNrOfImages())
     {
         XRCCTRL(*this, "output_normal", wxCheckBox)->SetValue(true);
         XRCCTRL(*this, "output_normal", wxCheckBox)->Enable(true);
-        XRCCTRL(*this, "output_normal_bitmap", wxCheckBox)->Enable(true);
+        XRCCTRL(*this, "output_normal_bitmap", wxStaticBitmap)->Enable(true);
         if(m_pano.getNrOfImages()==1 || m_stacks.size()==m_pano.getNrOfImages())
         {
             return;
         };
     };
     XRCCTRL(*this, "output_fused_blended", wxCheckBox)->Enable(true);
-    XRCCTRL(*this, "output_fused_blended_bitmap", wxCheckBox)->Enable(true);
+    XRCCTRL(*this, "output_fused_blended_bitmap", wxStaticBitmap)->Enable(true);
     XRCCTRL(*this, "output_blended_fused", wxCheckBox)->Enable(true);
-    XRCCTRL(*this, "output_blended_fused_bitmap", wxCheckBox)->Enable(true);
+    XRCCTRL(*this, "output_blended_fused_bitmap", wxStaticBitmap)->Enable(true);
     if(m_guiLevel!=GUI_SIMPLE)
     {
         XRCCTRL(*this, "output_hdr", wxCheckBox)->Enable(true);
-        XRCCTRL(*this, "output_hdr_bitmap", wxCheckBox)->Enable(true);
+        XRCCTRL(*this, "output_hdr_bitmap", wxStaticBitmap)->Enable(true);
     };
     if(m_pano.getNrOfImages() % m_stacks.size() == 0)
     {
@@ -197,6 +200,8 @@ void PanoOutputDialog::EnableOutputOptions()
         if(m_exposureLayers.size()==1)
         {
             XRCCTRL(*this, "output_normal", wxCheckBox)->SetValue(true);
+            XRCCTRL(*this, "output_normal", wxCheckBox)->Enable(true);
+            XRCCTRL(*this, "output_normal_bitmap", wxStaticBitmap)->Enable(true);
         }
         else
         {
