@@ -111,7 +111,7 @@ BEGIN_EVENT_TABLE(PanoPanel, wxPanel)
 END_EVENT_TABLE()
 
 PanoPanel::PanoPanel()
-    : pano(0), updatesDisabled(false), m_guiLevel(GUI_SIMPLE)
+    : pano(0), m_guiLevel(GUI_SIMPLE), updatesDisabled(false)
 {
 
 }
@@ -471,7 +471,7 @@ void PanoPanel::UpdateDisplay(const HuginBase::PanoramaOptions & opt, const bool
     m_BlenderChoice->Show(m_guiLevel>GUI_SIMPLE);
     // select correct blending mechanism
     SelectListValue(m_BlenderChoice, opt.blendMode);
-    XRCCTRL(*this, "pano_button_blender_opts", wxButton)->Enable(blenderEnabled && opt.blendMode!=HuginBase::PanoramaOptions::INTERNAL_BLEND);
+    XRCCTRL(*this, "pano_button_blender_opts", wxButton)->Enable(blenderEnabled);
     XRCCTRL(*this, "pano_button_blender_opts", wxButton)->Show(m_guiLevel>GUI_SIMPLE);
     XRCCTRL(*this, "pano_text_blender", wxStaticText)->Enable(blenderEnabled);
     XRCCTRL(*this, "pano_text_blender", wxStaticText)->Show(m_guiLevel>GUI_SIMPLE);
@@ -850,9 +850,42 @@ void PanoPanel::OnBlenderOptions(wxCommandEvent & e)
                 new PanoCommand::SetPanoOptionsCmd( *pano, opt )
                 );
         }
-    } else {
-        wxLogError(_(" PTblender options not yet implemented"));
-    }
+    } 
+    else
+    {
+        if (opt.blendMode == HuginBase::PanoramaOptions::INTERNAL_BLEND)
+        {
+            wxDialog dlg;
+            wxXmlResource::Get()->LoadDialog(&dlg, this, wxT("verdandi_options_dialog"));
+            wxChoice * verdandiBlendModeChoice = XRCCTRL(dlg, "verdandi_blend_mode_choice", wxChoice);
+            if (opt.verdandiOptions.find("--seam=blend")!=std::string::npos)
+            {
+                verdandiBlendModeChoice->SetSelection(1);
+            }
+            else
+            {
+                verdandiBlendModeChoice->SetSelection(0);
+            };
+            dlg.CentreOnParent();
+
+            if (dlg.ShowModal() == wxID_OK)
+            {
+                if (verdandiBlendModeChoice->GetSelection() == 1)
+                {
+                    opt.verdandiOptions = "--seam=blend";
+                }
+                else
+                {
+                    opt.verdandiOptions = "";
+                };
+                PanoCommand::GlobalCmdHist::getInstance().addCommand(new PanoCommand::SetPanoOptionsCmd(*pano, opt));
+            };
+        }
+        else
+        {
+            wxLogError(_(" PTblender options not yet implemented"));
+        };
+    };
 }
 
 void PanoPanel::FusionChanged(wxCommandEvent & e)
@@ -1039,7 +1072,7 @@ void PanoPanel::DoStitch()
         DEBUG_ERROR("hugin_stitch_project could not be found in the bundle.");
         return;
     }
-    hugin_stitch_project = wxQuoteFilename(hugin_stitch_project);
+    hugin_stitch_project = hugin_utils::wxQuoteFilename(hugin_stitch_project);
 #elif defined __WXMAC__
     // HuginStitchProject installed in INSTALL_OSX_BUNDLE_DIR
     wxFileName hugin_stitch_project_app(wxT(INSTALL_OSX_BUNDLE_DIR), wxEmptyString);
@@ -1223,8 +1256,8 @@ void PanoPanel::DoSendToBatch()
 			//Found PTBatcherGui inside the (registered) PTBatcherGui bundle. Call it directly.
 			//We need to call the binary from it's own bundle and not from the hugin bundle otherwise we get no menu as OSX assumes that the hugin bundle
 			//will provide the menu
-			cmd = wxQuoteString(cmd); 
-            cmd += wxT(" ")+switches+hugin_utils::wxQuoteFilename(projectFile)+wxT(" ")+hugin_utils::wxQuoteFilename(dlg.GetPath());	
+			cmd = hugin_utils::wxQuoteString(cmd); 
+            cmd += wxT(" ") + switches + hugin_utils::wxQuoteFilename(projectFile) + wxT(" ") + hugin_utils::wxQuoteFilename(dlg.GetPath());
 			wxExecute(cmd);
 		}
 		else
@@ -1308,7 +1341,7 @@ void PanoPanel::DoUserDefinedStitch()
         DEBUG_ERROR("hugin_stitch_project could not be found in the bundle.");
         return;
     }
-    hugin_stitch_project = wxQuoteFilename(hugin_stitch_project);
+    hugin_stitch_project = hugin_utils::wxQuoteFilename(hugin_stitch_project);
 #elif defined __WXMAC__
     // HuginStitchProject installed in INSTALL_OSX_BUNDLE_DIR
     wxFileName hugin_stitch_project_app(wxT(INSTALL_OSX_BUNDLE_DIR), wxEmptyString);
