@@ -32,9 +32,6 @@
 #include <wx/platform.h>
 
 //multitexture feature requires glew on some systems
-#if !defined Hugin_shared || !defined _WINDOWS
-#define GLEW_STATIC
-#endif
 #include <GL/glew.h>
 
 #ifdef __WXMAC__
@@ -62,16 +59,52 @@
 bool PreviewIdentifyTool::texture_created = false;
 unsigned int PreviewIdentifyTool::circle_border_tex;
 unsigned int PreviewIdentifyTool::rectangle_border_tex;
+unsigned int PreviewIdentifyTool::font_tex;
+unsigned int PreviewIdentifyTool::font_list;
+std::vector<int> PreviewIdentifyTool::m_glyphWidth;
 
-PreviewIdentifyTool::PreviewIdentifyTool(ToolHelper *helper,
-                                         GLPreviewFrame *owner)
+#define FONT_TEXTURE_HEIGHT 75
+wxBitmap GenerateFontTexture(const int textureHeight, int& textureWidth, std::vector<int>& glyphWidth)
+{
+    wxBitmap bitmap(10 * textureHeight, textureHeight);
+    wxMemoryDC dc(bitmap);
+    dc.SetBackground(*wxBLACK_BRUSH);
+    dc.Clear();
+#if wxCHECK_VERSION(3,0,0)
+    wxFont font(wxSize(0, textureHeight), wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_BOLD);
+    dc.SetFont(font);
+#else
+    wxFont* font=wxFont::New(wxSize(0, textureHeight), wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_BOLD, false, wxT(""));
+    dc.SetFont(*font);
+#endif    
+    dc.SetTextForeground(*wxWHITE);
+    dc.DrawText(wxT("0123456789"), 0, 0);
+    textureWidth = 0;
+    glyphWidth.resize(10, 0);
+    for (int i = 0; i < 10; ++i)
+    {
+        wxString number;
+        number << i;
+        wxSize textSize = dc.GetTextExtent(number);
+        textureWidth += textSize.GetWidth();
+        glyphWidth[i] = textSize.GetWidth();
+    };
+#if !wxCHECK_VERSION(3,0,0)
+    delete font;
+#endif  
+    dc.SelectObject(wxNullBitmap);
+    return bitmap;
+}
+
+PreviewIdentifyTool::PreviewIdentifyTool(ToolHelper *helper, GLPreviewFrame *owner, bool showNumbers)
     : Tool(helper)
 {
-    holdControl = false;
-    constantOn = false;
-    holdLeft = false;
-    stopUpdating = true;
-    preview_frame = owner;
+    m_holdControl = false;
+    m_constantOn = false;
+    m_holdLeft = false;
+    m_stopUpdating = true;
+    m_preview_frame = owner;
+    m_showNumbers = showNumbers;
     if (!texture_created) {
         // make the textures. We have a circle border and a square one.
         // the textures are white with a the alpha chanel forming a border.
@@ -85,7 +118,7 @@ PreviewIdentifyTool::PreviewIdentifyTool(ToolHelper *helper,
             // In the rectangle texture, the middle is 1/4 opaque, the outer pixels
             // are completely transparent, and one pixel in from the edges is
             // a completly opaque line.
-            unsigned char rect_tex_data[rect_ts][rect_ts][2];
+            GLubyte rect_tex_data[rect_ts][rect_ts][2];
             // make everything white
             for (unsigned int x = 0; x < rect_ts; x++)
             {
@@ -132,7 +165,7 @@ PreviewIdentifyTool::PreviewIdentifyTool(ToolHelper *helper,
             // enlarge it so that the circle apears less blocky. We don't want to
             // make it equally sharper however, so we make it a bit fuzzier by
             // blending.
-            unsigned char circle_tex_data[circle_ts][circle_ts][2];
+            GLubyte circle_tex_data[circle_ts][circle_ts][2];
             for (unsigned int x = 0; x < circle_ts; x++)
             {
                 for (unsigned int y = 0; y < circle_ts; y++)
@@ -170,14 +203,64 @@ PreviewIdentifyTool::PreviewIdentifyTool(ToolHelper *helper,
             glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP);
             glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP);
         }
+        {
+            int textureWidth;
+            wxBitmap fontTexture(GenerateFontTexture(FONT_TEXTURE_HEIGHT, textureWidth, m_glyphWidth));
+            wxImage image = fontTexture.ConvertToImage();
+            glGenTextures(1, (GLuint*)&font_tex);
+            glBindTexture(GL_TEXTURE_2D, font_tex);
+            GLubyte* font_tex_data = new GLubyte[FONT_TEXTURE_HEIGHT * textureWidth * 2];
+            for (size_t x = 0; x < textureWidth; ++x)
+            {
+                for (size_t y = 0; y < FONT_TEXTURE_HEIGHT; ++y)
+                {
+                    const unsigned char value = image.GetRed(x, y);
+                    font_tex_data[2 * y * textureWidth + 2 * x] = value;
+                    font_tex_data[2 * y * textureWidth + 2 * x + 1] = value;
+                };
+            };
+            glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+            glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
+            gluBuild2DMipmaps(GL_TEXTURE_2D, GL_LUMINANCE_ALPHA, textureWidth, FONT_TEXTURE_HEIGHT,
+                GL_LUMINANCE_ALPHA, GL_UNSIGNED_BYTE, font_tex_data);
+            glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER,
+                GL_LINEAR_MIPMAP_LINEAR);
+            delete[] font_tex_data;
+
+            font_list = glGenLists(10);
+            float posX = 0;
+            for (int loop = 0; loop<10; loop++)
+            {
+                glNewList(font_list + loop, GL_COMPILE);
+                glBegin(GL_QUADS);
+                glTexCoord2f(posX, 0);
+                glVertex2i(0, 0);
+                glTexCoord2f(posX + m_glyphWidth[loop] / static_cast<float>(textureWidth), 0);
+                glVertex2i(m_glyphWidth[loop], 0);
+                glTexCoord2f(posX + m_glyphWidth[loop] / static_cast<float>(textureWidth), 1);
+                glVertex2i(m_glyphWidth[loop], FONT_TEXTURE_HEIGHT);
+                glTexCoord2f(posX, 1);
+                glVertex2i(0, FONT_TEXTURE_HEIGHT);
+                glEnd();
+                glTranslatef(m_glyphWidth[loop], 0, 0);
+                glEndList();
+                posX += m_glyphWidth[loop] / static_cast<float>(textureWidth);
+            }
+        }
         texture_created = true;
     }
 }
 PreviewIdentifyTool::~PreviewIdentifyTool()
 {
-    // free the textures
-    glDeleteTextures(1, (GLuint*) &rectangle_border_tex);
-    glDeleteTextures(1, (GLuint*) &circle_border_tex);
+    if (texture_created)
+    {
+        // free the textures
+        glDeleteTextures(1, (GLuint*)&rectangle_border_tex);
+        glDeleteTextures(1, (GLuint*)&circle_border_tex);
+        glDeleteLists(font_list, 10);
+        glDeleteTextures(1, (GLuint*)&font_tex);
+        texture_created = false;
+    };
 }
 
 void PreviewIdentifyTool::Activate()
@@ -192,8 +275,8 @@ void PreviewIdentifyTool::Activate()
     // Assume that there are no images under the mouse when the tool is
     // activated. This should be fine if the user clicks the button to activate
     // the tool.
-    image_set.clear();
-    mouse_is_over_button = false;
+    m_image_set.clear();
+    m_mouse_is_over_button = false;
     /* TODO if it becomes possible to activate the tool by a keyboard shortcut
      * or something, call ImagesUnderMouseChangedEvent() to make sure we display
      * indicators for images currently under the cursor. */
@@ -203,25 +286,25 @@ void PreviewIdentifyTool::Activate()
 }
 
 void PreviewIdentifyTool::StopUpdating() {
-    if (!image_set.empty()) {
-        std::set<unsigned int>::iterator iterator;
-        for (iterator = image_set.begin(); iterator != image_set.end(); iterator++)
+    if (!m_image_set.empty())
+    {
+        for (auto& img : m_image_set)
         {
-            DEBUG_ASSERT(*iterator < helper->GetPanoramaPtr()->getNrOfImages());
+            DEBUG_ASSERT(img < helper->GetPanoramaPtr()->getNrOfImages());
             // reset this button to its default system colour.
-            preview_frame->SetImageButtonColour(*iterator, 0, 0, 0);
+            m_preview_frame->SetImageButtonColour(img, 0, 0, 0);
             // remove the notification
-            helper->DoNotNotifyMeBeforeDrawing(*iterator, this);
+            helper->DoNotNotifyMeBeforeDrawing(img, this);
         }
     }
-    image_set.clear();
-    preview_frame->UpdateIdentifyTools(image_set);
-    stopUpdating = true;
+    m_image_set.clear();
+    m_preview_frame->UpdateIdentifyTools(m_image_set);
+    m_stopUpdating = true;
     ForceRedraw();
 }
 
 void PreviewIdentifyTool::ContinueUpdating() {
-    stopUpdating = false;
+    m_stopUpdating = false;
     ImagesUnderMouseChangedEvent();
 }
 
@@ -231,28 +314,28 @@ void PreviewIdentifyTool::MouseMoveEvent(double x, double y, wxMouseEvent & e)
     bool stop = false;
     bool start = false;
 
-    if (constantOn) {
-        if (e.Dragging() && !(holdLeft)) {
+    if (m_constantOn) {
+        if (e.Dragging() && !(m_holdLeft)) {
             stop = true;
-            stopUpdating = true;
+            m_stopUpdating = true;
         }
 
-        if (stopUpdating && !e.LeftIsDown() && !e.MiddleIsDown() && !e.RightIsDown()) {
+        if (m_stopUpdating && !e.LeftIsDown() && !e.MiddleIsDown() && !e.RightIsDown()) {
             start = true;
         }
     }
 
-    if (holdControl && !e.m_controlDown) {
-        holdControl = false;
-        if (!constantOn) {
+    if (m_holdControl && !e.m_controlDown) {
+        m_holdControl = false;
+        if (!m_constantOn) {
             stop = true;
         }
     }
     
-    if (!holdControl && e.m_controlDown) {
-        holdControl = true;
+    if (!m_holdControl && e.m_controlDown) {
+        m_holdControl = true;
         stop = false;
-        if (stopUpdating) {
+        if (m_stopUpdating) {
             start = true;
         }
     }
@@ -270,24 +353,24 @@ void PreviewIdentifyTool::KeypressEvent(int keycode, int modifierss, int pressed
 
     if (keycode == WXK_CONTROL) {
         if (pressed) {
-            holdControl = true;
+            m_holdControl = true;
             ContinueUpdating();
         } else {
-            if(holdControl) {
+            if(m_holdControl) {
                 StopUpdating();
             }
-            holdControl = false;
+            m_holdControl = false;
         }
     }
 }
 
 void PreviewIdentifyTool::setConstantOn(bool constant_on_in) {
-    constantOn = constant_on_in;
+    m_constantOn = constant_on_in;
     if (constant_on_in) {
-        stopUpdating = false;
+        m_stopUpdating = false;
         ContinueUpdating();
     } else {
-        stopUpdating = true;
+        m_stopUpdating = true;
         StopUpdating();
     }
 
@@ -296,7 +379,7 @@ void PreviewIdentifyTool::setConstantOn(bool constant_on_in) {
 
 void PreviewIdentifyTool::ImagesUnderMouseChangedEvent()
 {
-    if (stopUpdating) {
+    if (m_stopUpdating) {
         return;
     }
     
@@ -304,14 +387,14 @@ void PreviewIdentifyTool::ImagesUnderMouseChangedEvent()
     
     //UpdateIdentifyTools() will unrequest notification for the old indicators,
     //reset the button colors, request notification for the new ones, swap in
-    //image_set with new_image_set, and force a redraw for all three
+    //m_image_set with new_image_set, and force a redraw for all three
     //PreviewIdentifyTool objects in GLPreviewFrame. This has the effect of 
     //displaying the indicators in both the preview and overview when you move
     //your mouse over either when the Identify button is toggled on. 
-    preview_frame->UpdateIdentifyTools(new_image_set);
+    m_preview_frame->UpdateIdentifyTools(new_image_set);
     
     // if there is exactly two images, tell the user they can click to edit CPs.
-    if (image_set.size() == 2)
+    if (m_image_set.size() == 2)
     {
          helper->SetStatusMessage(_("Click to create or edit control points here."));
     } else {
@@ -322,15 +405,14 @@ void PreviewIdentifyTool::ImagesUnderMouseChangedEvent()
 void PreviewIdentifyTool::AfterDrawImagesEvent()
 {
     // we draw the partly transparent identification boxes over the top of the
-    // entire stack of images in image_set so that the extents of images in the
+    // entire stack of images in m_image_set so that the extents of images in the
     // background are clearly marked.
-    unsigned int num_images = image_set.size();
+    const unsigned int num_images = m_image_set.size();
     // draw the actual images
     // the preview draws them in reverse order, so the lowest numbered appears
     // on top. We will folow this convention to avoid confusion.
     glMatrixMode(GL_MODELVIEW);
-    std::set<unsigned int>::reverse_iterator it;
-    for (it = image_set.rbegin(); it != image_set.rend(); it++)
+    for (auto it = m_image_set.rbegin(); it != m_image_set.rend(); ++it)
     {
         DEBUG_ASSERT(*it < helper->GetPanoramaPtr()->getNrOfImages());
         helper->GetViewStatePtr()->GetTextureManager()->
@@ -343,7 +425,9 @@ void PreviewIdentifyTool::AfterDrawImagesEvent()
     glEnable(GL_BLEND);
     glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
     unsigned int image_counter = 0;
-    for (it = image_set.rbegin(); it != image_set.rend(); it++)
+    const unsigned int canvasWidth = helper->GetViewStatePtr()->GetOptions()->getWidth();
+    const unsigned int canvasHeight = helper->GetViewStatePtr()->GetOptions()->getHeight();
+    for (auto it = m_image_set.rbegin(); it != m_image_set.rend(); ++it)
     {
         glMatrixMode(GL_TEXTURE);
         // Use the mask to alter the shape of the identification boxes, but
@@ -413,7 +497,55 @@ void PreviewIdentifyTool::AfterDrawImagesEvent()
         glMatrixMode(GL_TEXTURE);
         glPopMatrix();
         // tell the preview frame to update the button to show the same colour.
-        preview_frame->SetImageButtonColour(*it, r, g, b);
+        m_preview_frame->SetImageButtonColour(*it, r, g, b);
+        // draw number
+        // this code works only for the preview window, not for the panosphere or mosaic plane
+        if (m_showNumbers)
+        {
+        HuginBase::PanoramaOptions* opts = helper->GetViewStatePtr()->GetOptions();
+        HuginBase::SrcPanoImage* img = helper->GetViewStatePtr()->GetSrcImage(*it);
+        HuginBase::PTools::Transform transform;
+        transform.createInvTransform(*img, *opts);
+        hugin_utils::FDiff2D imageCenter(crop_region.upperLeft() + crop_region.size() / 2);
+        hugin_utils::FDiff2D imageCenterPano;
+        if (transform.transformImgCoord(imageCenterPano, imageCenter) && !wxGetKeyState(WXK_ALT))
+        {
+            glBindTexture(GL_TEXTURE_2D, font_tex);
+            if (helper->GetViewStatePtr()->GetSupportMultiTexture())
+            {
+                glActiveTexture(GL_TEXTURE1);
+                glDisable(GL_TEXTURE_2D);
+                glActiveTexture(GL_TEXTURE0);
+            };
+            glMatrixMode(GL_MODELVIEW);
+            glPushMatrix();
+            wxString number;
+            number << *it;
+            int textWidth = 0;
+            unsigned char* listIndex = new unsigned char[number.Length()];
+            for (size_t i = 0; i < number.Length(); ++i)
+            {
+#if wxCHECK_VERSION(3,0,0)
+                textWidth += m_glyphWidth[number[i].GetValue() - 48];
+                listIndex[i] = number[i].GetValue() - 48;
+#else
+                textWidth += m_glyphWidth[number[i] - 48];
+                listIndex[i] = number[i] - 48;
+#endif
+            }
+            float scaleFactor = std::min(canvasWidth, canvasHeight) / static_cast<float>(FONT_TEXTURE_HEIGHT) / 10;
+            imageCenterPano.x = std::min<double>(std::max<double>(imageCenterPano.x, textWidth*scaleFactor / 2.0), canvasWidth - textWidth * scaleFactor / 2.0);
+            imageCenterPano.y = std::min<double>(std::max<double>(imageCenterPano.y, FONT_TEXTURE_HEIGHT*scaleFactor / 2.0), canvasHeight - FONT_TEXTURE_HEIGHT * scaleFactor / 2.0);
+            glTranslatef(imageCenterPano.x, imageCenterPano.y, 0);
+            glScalef(scaleFactor, scaleFactor, 1.0);
+            glTranslatef(-textWidth / 2, -FONT_TEXTURE_HEIGHT / 2, 0);
+            glListBase(font_list);
+            glCallLists(number.Length(), GL_UNSIGNED_BYTE, listIndex);
+            glMatrixMode(GL_MODELVIEW);
+            glPopMatrix();
+            delete[] listIndex;
+        };
+        };
     }
     // set stuff back how we found it.
     glMatrixMode(GL_MODELVIEW);
@@ -425,7 +557,7 @@ bool PreviewIdentifyTool::BeforeDrawImageEvent(unsigned int image)
 {
     // Delay drawing of images, so we can show them on top of the others.
     DEBUG_ASSERT(image < helper->GetPanoramaPtr()->getNrOfImages());
-    if (image_set.count(image)) return false;
+    if (m_image_set.count(image)) return false;
     return true;
 }
 
@@ -433,30 +565,30 @@ void PreviewIdentifyTool::ShowImageNumber(unsigned int image)
 {
     DEBUG_ASSERT(image < helper->GetPanoramaPtr()->getNrOfImages());
     // Add this image to the set of images drawn.
-    if (!image_set.count(image))
+    if (!m_image_set.count(image))
     {
         // it is not already in the set. Add it now
-        image_set.insert(image);
+        m_image_set.insert(image);
         // we want notification of when it is drawn so we can delay drawing.
         helper->NotifyMeBeforeDrawing(image, this);
         //  now we want a redraw.
         ForceRedraw();
     }
-    mouse_over_image = image;
-    mouse_is_over_button = true;
+    m_mouse_over_image = image;
+    m_mouse_is_over_button = true;
 }
 
 void PreviewIdentifyTool::StopShowingImages()
 {
-    if (mouse_is_over_button)
+    if (m_mouse_is_over_button)
     {
         // set the colour to the image the user just moused off to the default.
-        preview_frame->SetImageButtonColour(mouse_over_image, 0, 0, 0);
-        helper->DoNotNotifyMeBeforeDrawing(mouse_over_image, this);
-        image_set.erase(mouse_over_image);
+        m_preview_frame->SetImageButtonColour(m_mouse_over_image, 0, 0, 0);
+        helper->DoNotNotifyMeBeforeDrawing(m_mouse_over_image, this);
+        m_image_set.erase(m_mouse_over_image);
         // now redraw without the indicator.
         ForceRedraw();
-        mouse_is_over_button = false;
+        m_mouse_is_over_button = false;
     }    
 }
 
@@ -510,36 +642,36 @@ void PreviewIdentifyTool::MouseButtonEvent(wxMouseEvent & e)
 
     if ( e.LeftDown() && helper->IsMouseOverPano())
     {   
-        holdLeft = true;
+        m_holdLeft = true;
     } 
 
-    if (holdLeft && e.LeftUp() && (image_set.size()==1 || image_set.size() == 2)) 
+    if (m_holdLeft && e.LeftUp() && (m_image_set.size()==1 || m_image_set.size() == 2)) 
     {
-        holdLeft = false;
-        if (constantOn || e.CmdDown())
+        m_holdLeft = false;
+        if (m_constantOn || e.CmdDown())
         {
             // when there are only two images with indicators shown, show the
             // control point editor with those images when left clicked.
-            if(image_set.size()==2)
+            if(m_image_set.size()==2)
             {
-                MainFrame::Get()->ShowCtrlPointEditor(*(image_set.begin()),
-                                                        *(++image_set.begin()));
+                MainFrame::Get()->ShowCtrlPointEditor(*(m_image_set.begin()),
+                                                        *(++m_image_set.begin()));
             }
             else
             {
-                MainFrame::Get()->ShowMaskEditor(*image_set.begin());
+                MainFrame::Get()->ShowMaskEditor(*m_image_set.begin());
             };
             MainFrame::Get()->Raise();
         }
     }
 
-    if (holdLeft && !(e.LeftIsDown())) {
-        holdLeft = false;
+    if (m_holdLeft && !(e.LeftIsDown())) {
+        m_holdLeft = false;
     }
 
-    if (constantOn) {
+    if (m_constantOn) {
         if (e.ButtonUp() && !e.MiddleIsDown() && !e.RightIsDown()) {
-            stopUpdating = false;
+            m_stopUpdating = false;
             ImagesUnderMouseChangedEvent();
         }
     }
@@ -551,21 +683,21 @@ void PreviewIdentifyTool::UpdateWithNewImageSet(std::set<unsigned int> new_image
     // If we are currently showing indicators for some of the images, we want
     // to work out which ones are not in the new set, so we can set their
     // buttons back to the system colour.
-    if (!image_set.empty())
+    if (!m_image_set.empty())
     {
         HuginBase::UIntSet difference;
-        std::set_difference (image_set.begin(), image_set.end(),
+        std::set_difference (m_image_set.begin(), m_image_set.end(),
                              new_image_set.begin(), new_image_set.end(),
                              std::inserter(difference,difference.end()));
         if (!difference.empty())
         {
-            for (HuginBase::UIntSet::iterator iterator = difference.begin(); iterator != difference.end(); iterator++)
+            for (auto& img : difference)
             {
-                DEBUG_ASSERT(*iterator < helper->GetPanoramaPtr()->getNrOfImages());
+                DEBUG_ASSERT(img < helper->GetPanoramaPtr()->getNrOfImages());
                 // reset this button to its default system colour.
-                preview_frame->SetImageButtonColour(*iterator, 0, 0, 0);
+                m_preview_frame->SetImageButtonColour(img, 0, 0, 0);
                 // remove the notification
-                helper->DoNotNotifyMeBeforeDrawing(*iterator, this);
+                helper->DoNotNotifyMeBeforeDrawing(img, this);
             }
         }
     }
@@ -575,20 +707,20 @@ void PreviewIdentifyTool::UpdateWithNewImageSet(std::set<unsigned int> new_image
     {
         HuginBase::UIntSet difference;
         std::set_difference(new_image_set.begin(), new_image_set.end(),
-            image_set.begin(), image_set.end(),
+            m_image_set.begin(), m_image_set.end(),
             std::inserter(difference, difference.end()));
         if (!difference.empty())
         {
-            for (HuginBase::UIntSet::iterator iterator = difference.begin(); iterator != difference.end(); iterator++)
+            for (auto& img : difference)
             {
-                DEBUG_ASSERT(*iterator < helper->GetPanoramaPtr()->getNrOfImages());
+                DEBUG_ASSERT(img < helper->GetPanoramaPtr()->getNrOfImages());
                 // get notification of when this is about to be drawn.
-                helper->NotifyMeBeforeDrawing(*iterator, this);
+                helper->NotifyMeBeforeDrawing(img, this);
             }
         }
     };
     // remember the new set.
-    image_set.swap(new_image_set);
+    m_image_set.swap(new_image_set);
 
     // Redraw with new indicators. Since the indicators aren't part of the
     // panorama and none of it is likely to change, we have to persuade the
