@@ -81,10 +81,10 @@ public:
 
 PreviewLayoutLinesTool::PreviewLayoutLinesTool(ToolHelper *helper)
     : Tool(helper),
+      m_holdOnNear(false),
       m_updateStatistics(true),
       m_nearestLine(-1),
-      m_useNearestLine(false),
-      m_holdOnNear(false)
+      m_useNearestLine(false)
 {
     helper->GetPanoramaPtr()->addObserver(this);
     // make the textures. We have a circle border and a square one.
@@ -98,7 +98,7 @@ PreviewLayoutLinesTool::PreviewLayoutLinesTool(ToolHelper *helper)
     // In the rectangle texture, the middle is 1/8 opaque, the outer pixels
     // are completely transparent, and one pixel in from the edges is
     // a completly opaque line.
-    unsigned char rect_tex_data[rect_ts][rect_ts][2];
+    GLubyte rect_tex_data[rect_ts][rect_ts][2];
     // make everything white
     for (unsigned int x = 0; x < rect_ts; x++)
     {
