@@ -37,20 +37,14 @@
 
 #include "vigra/stdimage.hxx"
 #include "vigra/resizeimage.hxx"
-#ifdef HAVE_CXX11
 #include <functional>  // std::bind
-#else
-#include <boost/bind.hpp>
-#endif
 #include "base_wx/wxImageCache.h"
 #include "photometric/ResponseTransform.h"
 #include "panodata/Mask.h"
+#include <lcms2.h>
 
 // The OpenGL Extension wrangler libray will find extensions and the latest
 // supported OpenGL version on all platforms.
-#if !defined Hugin_shared || !defined _WINDOWS
-#define GLEW_STATIC
-#endif
 #include <GL/glew.h>
 #include <wx/platform.h>
 
@@ -125,18 +119,20 @@ void TextureManager::DrawImage(unsigned int image_number,
             glColor4f(1.0, 1.0, 1.0, 1.0);
             // double the brightness for colour components until it is almost
             // right, however limit it incase it is really bright.
-            bool r, g, b;
+            bool r = (scale[0] > 2.0);
+            bool g = (scale[1] > 2.0);
+            bool b = (scale[2] > 2.0);
             unsigned short int count = 0;
-            while ((   (r = (scale[0] > 2.0))
-                   || (g = (scale[1] > 2.0))
-                   || (b = (scale[2] > 2.0)))
-                   && count < 9)
+            while ((r || g || b) && count < 9)
             {
                 glColor4f(r ? 1.0 : 0.0, g ? 1.0 : 0.0, b ? 1.0 : 0.0, 1.0);
                 glCallList(display_list);
                 if (r) scale[0] /= 2.0;
                 if (g) scale[1] /= 2.0;
                 if (b) scale[2] /= 2.0;
+                r = (scale[0] > 2.0);
+                g = (scale[1] > 2.0);
+                b = (scale[2] > 2.0);
                 count++;
             }
             // now add on anything remaining.
@@ -251,7 +247,7 @@ void TextureManager::CheckUpdate()
 
     // now recalculate the best image sizes
     // The actual texture size is the biggest one possible withouth scaling the
-    // image up in any direction. We only specifiy mipmap levels we can fit in
+    // image up in any direction. We only specify mipmap levels we can fit in
     // a given amount of texture memory, while respecting the image's FOV.
     int texels_used = 0;
     double ideal_texels_used = 0.0;
@@ -263,12 +259,12 @@ void TextureManager::CheckUpdate()
         HuginBase::SrcPanoImage *img_p = view_state->GetSrcImage(image_index);
         TextureKey key(img_p, &photometric_correct);
         it = textures.find(key);
-        TextureInfo *texinfo;
         /* This section would allow us to reuse textures generated when we want
          * to change the size. It is not used as it causes segmentation faults
          * under Ubuntu 8.04's "ati" graphics driver.
          */
       #if 0
+        TextureInfo *texinfo;
         if (it == textures.end())
         {
             // We haven't seen this image before.
@@ -418,20 +414,17 @@ void TextureManager::CheckUpdate()
             //
             // remove duplicate key if exists
             TextureKey checkKey (img_p, &photometric_correct);
-            if (textures.find(checkKey) != textures.end()) {
-                // Already exists in map, remove it first before adding a new one
-                textures.erase(checkKey);
-            }
+            textures.erase(checkKey);
 
             std::pair<TexturesMap::iterator, bool> ins;
-            ins = textures.insert(std::pair<TextureKey, sharedPtrNamespace::shared_ptr<TextureInfo> >
+            ins = textures.insert(std::pair<TextureKey, std::shared_ptr<TextureInfo> >
                                  (TextureKey(img_p, &photometric_correct),
                 // the key is used to identify the image with (or without)
                 // photometric correction parameters.
-                              sharedPtrNamespace::make_shared<TextureInfo>(view_state, tex_width_p, tex_height_p)
+                              std::make_shared<TextureInfo>(view_state, tex_width_p, tex_height_p)
                             ));
            // create and upload the texture image
-           texinfo = (ins.first)->second.get();
+           TextureInfo* texinfo = (ins.first)->second.get();
            texinfo->DefineLevels(0, // minimum mip level
                                  // maximum mip level
                         tex_width_p > tex_height_p ? tex_width_p : tex_height_p,
@@ -562,7 +555,7 @@ void TextureManager::LoadingImageFinished(int min, int max,
     if (it != textures.end())
     {
         // new shared pointer to keep class alive
-        sharedPtrNamespace::shared_ptr<TextureInfo> tex(it->second);
+        std::shared_ptr<TextureInfo> tex(it->second);
         tex->DefineLevels(min, max, texture_photometric_correct, dest_img, state);
     };
 };
@@ -573,6 +566,7 @@ TextureManager::TextureInfo::TextureInfo(ViewState *new_view_state)
     DEBUG_ASSERT(0);
     m_viewState=new_view_state;
     has_active_masks=false;
+    has_mask=false;
     CreateTexture();
 }
 
@@ -581,6 +575,7 @@ TextureManager::TextureInfo::TextureInfo(ViewState *new_view_state, unsigned int
 {
     m_viewState=new_view_state;
     has_active_masks=false;
+    has_mask=false;
     width_p = width_p_in;
     height_p = height_p_in;
     width = 1 << width_p;
@@ -722,7 +717,7 @@ void TextureManager::TextureInfo::DefineLevels(int min,
     // remove some cache items if we are using lots of memory:
     ImageCache::getInstance().softFlush();
     DEBUG_INFO("Loading image");
-    std::string img_name = src_img.getFilename();
+    const std::string img_name = src_img.getFilename();
     ImageCache::EntryPtr entry = ImageCache::getInstance().getImageIfAvailable(img_name);
     if (!entry.get())
     {
@@ -734,23 +729,13 @@ void TextureManager::TextureInfo::DefineLevels(int min,
         // this can happen if a new project is opened during the loading cycling
         // so we go about LoadingImageFinished to check if the texture is still needed
         m_imageRequest->ready.push_back(
-#ifdef HAVE_CXX11
             std::bind(&TextureManager::LoadingImageFinished, m_viewState->GetTextureManager(),
                       min, max, photometric_correct, dest_img, src_img)
-#else
-            boost::bind(&TextureManager::LoadingImageFinished, m_viewState->GetTextureManager(),
-                        min, max, photometric_correct, dest_img, src_img)
-#endif
         );
         // After that, redraw the preview.
         m_imageRequest->ready.push_back(
-#ifdef HAVE_CXX11
             std::bind(&GLPreviewFrame::redrawPreview,
                       huginApp::getMainFrame()->getGLPreview())
-#else
-            boost::bind(&GLPreviewFrame::redrawPreview,
-                        huginApp::getMainFrame()->getGLPreview())
-#endif
         );
         
         // make a temporary placeholder image.
@@ -818,7 +803,7 @@ void TextureManager::TextureInfo::DefineLevels(int min,
                 for (int j = 0; j < placeholderWidth; j++)
                 {
                     // checkboard pattern
-                    GLubyte c = (i / 8 + j / 8) % 2 ? 63 : 191;
+                    GLubyte c = ((i / 8 + j / 8) % 2) ? 63 : 191;
                     placeholder_image[index++] = c;
                     placeholder_image[index++] = c;
                     placeholder_image[index++] = c;
@@ -837,8 +822,8 @@ void TextureManager::TextureInfo::DefineLevels(int min,
     // forget the request if we made one before.
     m_imageRequest = ImageCache::RequestPtr();
     DEBUG_INFO("Converting to 8 bits");
-    sharedPtrNamespace::shared_ptr<vigra::BRGBImage> img = entry->get8BitImage();
-    sharedPtrNamespace::shared_ptr<vigra::BImage> mask = entry->mask;
+    std::shared_ptr<vigra::BRGBImage> img = entry->get8BitImage();
+    std::shared_ptr<vigra::BImage> mask = entry->mask;
     // first make the biggest mip level.
     int wo = 1 << (width_p - min), ho = 1 << (height_p - min);
     if (wo < 1) wo = 1; if (ho < 1) ho = 1;
@@ -880,6 +865,35 @@ void TextureManager::TextureInfo::DefineLevels(int min,
             vigra::resizeImageNoInterpolation(srcImageRange(*(mask)),
                                               destImageRange(*out_alpha));
         }/**/
+        // prepare color management
+        cmsHPROFILE inputICC = NULL;
+        if (!entry->iccProfile->empty())
+        {
+            inputICC = cmsOpenProfileFromMem(entry->iccProfile->data(), entry->iccProfile->size());
+        };
+        cmsHTRANSFORM transform = NULL;
+        // do color correction only if input image has icc profile or if we found a monitor profile
+        if (inputICC != NULL || huginApp::Get()->HasMonitorProfile())
+        {
+            // check input profile
+            if (inputICC != NULL)
+            {
+                if (cmsGetColorSpace(inputICC) != cmsSigRgbData)
+                {
+                    cmsCloseProfile(inputICC);
+                    inputICC = NULL;
+                };
+            };
+            // if there is no icc profile in file fall back to sRGB
+            if (inputICC == NULL)
+            {
+                inputICC = cmsCreate_sRGBProfile();
+            };
+            // now build transform
+            transform = cmsCreateTransform(inputICC, TYPE_RGB_8,
+                huginApp::Get()->GetMonitorProfile(), TYPE_RGB_8,
+                INTENT_PERCEPTUAL, cmsFLAGS_BLACKPOINTCOMPENSATION);
+        };
         // now perform photometric correction
         if (photometric_correct)
         {
@@ -887,21 +901,21 @@ void TextureManager::TextureInfo::DefineLevels(int min,
             // setup photometric transform for this image type
             // this corrects for response curve, white balance, exposure and
             // radial vignetting
-            HuginBase::Photometric::InvResponseTransform <unsigned char, double>
-                                    invResponse(src_img);
-           // Assume LDR for now.
-           // if (m_destImg.outputMode == PanoramaOptions::OUTPUT_LDR) {
-               // select exposure and response curve for LDR output
-               std::vector<double> outLut;
-               // @TODO better handling of output EMoR parameters
-               // Hugin's stitcher is currently using the EMoR parameters of the first image
-               // as so called output EMoR parameter, so enforce this also for the fast
-               // preview window
-               // vigra_ext::EMoR::createEMoRLUT(dest_img.outputEMoRParams, outLut);
-               vigra_ext::EMoR::createEMoRLUT(m_viewState->GetSrcImage(0)->getEMoRParams(), outLut);
-               vigra_ext::enforceMonotonicity(outLut);
-               invResponse.setOutput(1.0/pow(2.0,dest_img.outputExposureValue),
-                                     outLut, 255.0);
+            HuginBase::Photometric::InvResponseTransform < unsigned char, double >
+                invResponse(src_img);
+            // Assume LDR for now.
+            // if (m_destImg.outputMode == PanoramaOptions::OUTPUT_LDR) {
+            // select exposure and response curve for LDR output
+            std::vector<double> outLut;
+            // @TODO better handling of output EMoR parameters
+            // Hugin's stitcher is currently using the EMoR parameters of the first image
+            // as so called output EMoR parameter, so enforce this also for the fast
+            // preview window
+            // vigra_ext::EMoR::createEMoRLUT(dest_img.outputEMoRParams, outLut);
+            vigra_ext::EMoR::createEMoRLUT(m_viewState->GetSrcImage(0)->getEMoRParams(), outLut);
+            vigra_ext::enforceMonotonicity(outLut);
+            invResponse.setOutput(1.0 / pow(2.0, dest_img.outputExposureValue),
+                outLut, 255.0);
             /*} else {
                // HDR output. not sure how that would be handled by the opengl
                // preview, though. It might be possible to apply a logarithmic
@@ -909,21 +923,47 @@ void TextureManager::TextureInfo::DefineLevels(int min,
                // in the OpenGL renderer?
                // TODO
                invResponse.setHDROutput();
-            }*/
+               }*/
             // now perform the corrections
-            double scale_x = (double) src_img.getSize().width() / (double) wo,
-                   scale_y = (double) src_img.getSize().height() / (double) ho;
-            for (int x = 0; x < wo; x++)
+            double scale_x = (double)src_img.getSize().width() / (double)wo,
+                scale_y = (double)src_img.getSize().height() / (double)ho;
+#pragma omp parallel for
+            for (int y = 0; y < ho; y++)
             {
-                for (int y = 0; y < ho; y++)
+                for (int x = 0; x < wo; x++)
                 {
-                    double sx = (double) x * scale_x,
-                           sy = (double) y * scale_y;
+                    double sx = (double)x * scale_x,
+                        sy = (double)y * scale_y;
                     out_img[y][x] = invResponse(out_img[y][x],
-                                                hugin_utils::FDiff2D(sx, sy));
+                        hugin_utils::FDiff2D(sx, sy));
                 }
+                // now take color profiles in file and of monitor into account
+                if (transform != NULL)
+                {
+                    cmsDoTransform(transform, out_img[y], out_img[y], out_img.width());
+                };
             }
         }
+        else
+        {
+            // no photometric correction
+            if (transform != NULL)
+            {
+#pragma omp parallel for
+                for (int y = 0; y < ho; y++)
+                {
+                    cmsDoTransform(transform, out_img[y], out_img[y], out_img.width());
+                };
+            };
+        };
+        if (transform != NULL)
+        {
+            cmsDeleteTransform(transform);
+        };
+        if (inputICC != NULL)
+        {
+            cmsCloseProfile(inputICC);
+        };
     }
     
     //  make all of the smaller ones until we are done.
@@ -937,8 +977,8 @@ void TextureManager::TextureInfo::DefineLevels(int min,
     if (has_mask)
     {
         // combine the alpha bitmap with the red green and blue one.
-        unsigned char *image = new unsigned char[ho * wo * 4];
-        unsigned char *pix_start = image;
+        GLubyte *image = new GLubyte[ho * wo * 4];
+        GLubyte *pix_start = image;
         for (int h = 0; h < ho; h++)
         {
             for (int w = 0; w < wo; w++)
@@ -1000,8 +1040,8 @@ void TextureManager::TextureInfo::DefineMaskTexture(const HuginBase::SrcPanoImag
 #ifdef __APPLE__
         // see comment to PreviewLayoutLinesTool::PreviewLayoutLinesTool
         // on MacOS a single alpha channel seems not to work, so this workaround
-        unsigned char *image = new unsigned char[maskSize * maskSize * 2];
-        unsigned char *pix_start = image;
+        GLubyte *image = new GLubyte[maskSize * maskSize * 2];
+        GLubyte *pix_start = image;
         for (int h = 0; h < maskSize; h++)
         {
             for (int w = 0; w < maskSize; w++)
