@@ -48,6 +48,7 @@
 #include "hugin/GLPreviewFrame.h"
 #include "base_wx/PTWXDlg.h"
 #include "base_wx/CommandHistory.h"
+#include "base_wx/wxcms.h"
 #include "base_wx/wxPanoCommand.h"
 #include "hugin/HtmlWindow.h"
 #include "hugin/treelistctrl.h"
@@ -63,6 +64,9 @@
 #include <wx/taskbarbutton.h>
 #endif
 #endif
+#ifdef __WXGTK3__
+#include <wx/platinfo.h>
+#endif
 
 #include <tiffio.h>
 
@@ -77,34 +81,50 @@ bool checkVersion(wxString v1, wxString v2)
     return doj::alphanum_comp(std::string(v1.mb_str(wxConvLocal)),std::string(v2.mb_str(wxConvLocal))) < 0;
 };
 
-using namespace hugin_utils;
-
-wxString Components2Str(const HuginBase::CPComponents & comp)
+wxString Components2Str(const HuginGraph::ImageGraph::Components & comp)
 {
     wxString ret;
     for (unsigned i=0; i < comp.size(); i++) {
-        ret = ret + wxT("[");
-        HuginBase::CPComponents::value_type::const_iterator it;
-        size_t c=0;
-        for (it = comp[i].begin();
-            it != comp[i].end();
-            ++it) 
+        ret.Append(wxT("["));
+        HuginGraph::ImageGraph::Components::value_type::const_iterator it = comp[i].begin();
+        while (it != comp[i].end())
         {
-            ret = ret + wxString::Format(wxT("%d"), (*it));
-            if (c+1 != comp[i].size()) {
-                ret = ret + wxT(", ");
+            unsigned int imgNr = *it;
+            ret << imgNr;
+            it++;
+            if (it != comp[i].end() && *it == imgNr + 1)
+            {
+                ret.Append(wxT("-"));
+                while (it != comp[i].end() && *it == imgNr + 1)
+                {
+                    ++it;
+                    ++imgNr;
+                };
+                ret << imgNr;
+                if (it != comp[i].end())
+                {
+                    ret.Append(wxT(", "));
+                };
             }
-            c++;
-        }
-        if (i+1 != comp.size())
-            ret = ret + wxT("], ");
-        else
-            ret = ret + wxT("]");
+            else
+            {
+                if (it != comp[i].end())
+                {
+                    ret.Append(wxT(", "));
+                };
+            };
+        };
+
+        ret.Append(wxT("]"));
+        if (i + 1 != comp.size())
+        {
+            ret.Append(wxT(", "));
+        };
     }
     return ret;
 }
 
-#if _WINDOWS && defined Hugin_shared
+#if defined _WIN32 && defined Hugin_shared
 DEFINE_LOCAL_EVENT_TYPE( EVT_IMAGE_READY )
 #else
 DEFINE_EVENT_TYPE( EVT_IMAGE_READY )
@@ -121,6 +141,7 @@ huginApp::huginApp()
 {
     DEBUG_TRACE("ctor");
     m_this=this;
+    m_monitorProfile = NULL;
 #if wxUSE_ON_FATAL_EXCEPTION
     wxHandleFatalExceptions();
 #endif
@@ -138,6 +159,11 @@ huginApp::~huginApp()
 
 //    delete frame;
     HuginBase::LensDB::LensDB::Clean();
+    // delete monitor profile
+    if (m_monitorProfile)
+    {
+        cmsCloseProfile(m_monitorProfile);
+    };
     DEBUG_TRACE("dtor end");
 }
 
@@ -204,15 +230,7 @@ bool huginApp::OnInit()
         }
     }
 #endif
-    {
-        wxString thePath = MacGetPathToBundledResourceFile(CFSTR("locale"));
-        if(thePath != wxT(""))
-            locale.AddCatalogLookupPathPrefix(thePath);
-        else {
-            wxMessageBox(_("Translations not found in bundle"), _("Fatal Error"));
-            return false;
-        }
-    }
+    
 	
 #else
     // add the locale directory specified during configure
@@ -234,6 +252,9 @@ bool huginApp::OnInit()
     config->Flush();
 
     // initialize i18n
+#if defined _MSC_VER && defined Hugin_shared
+    setlocale(LC_NUMERIC, "");
+#endif
     int localeID = config->Read(wxT("language"), (long) HUGIN_LANGUAGE);
     DEBUG_TRACE("localeID: " << localeID);
     {
@@ -311,12 +332,35 @@ bool huginApp::OnInit()
     m_macInitDone=false;
     m_macOpenFileOnStart=false;
 #endif
+    // read monitor profile
+    HuginBase::Color::GetMonitorProfile(m_monitorProfileName, m_monitorProfile);
     // create main frame
     frame = new MainFrame(NULL, pano);
     SetTopWindow(frame);
 
     // setup main frame size, after it has been created.
+#ifdef __WXGTK3__
+    if(wxPlatformInfo::Get().CheckToolkitVersion(3,20))
+    {
+        // workaround for wxWidgets bug http://trac.wxwidgets.org/ticket/17585
+        // with GTK3+ 3.20 the initial position/size of the sizer is not
+        // correctly calculated, if works when manually resizing the window
+        // so we need manually call the resizing function, but the sizes are
+        // only refreshed when before outstanding calculations are done in
+        // wxYield()
+        wxYield();
+        RestoreFramePosition(frame, wxT("MainFrame"));
+        wxYield();
+        frame->PostSizeEvent();
+        wxYield();
+    }
+    else
+    {
+        RestoreFramePosition(frame, wxT("MainFrame"));
+    }
+#else
     RestoreFramePosition(frame, wxT("MainFrame"));
+#endif
 #ifdef __WXMSW__
     provider->SetHelpController(&frame->GetHelpController());
     frame->GetHelpController().Initialize(m_xrcPrefix+wxT("data/hugin_help_en_EN.chm"));
@@ -422,9 +466,9 @@ bool huginApp::OnInit()
             frame->LoadProjectFile(file.GetFullPath());
         } else {
             std::vector<std::string> filesv;
+            bool actualPathSet = false;
             for (int i=1; i< argc; i++) 
             {
-                bool actualPathSet = false;
 #if defined __WXMSW__
                 //expand wildcards
                 wxFileName fileList(argv[i]);
@@ -511,6 +555,10 @@ bool huginApp::OnInit()
 int huginApp::OnExit()
 {
     DEBUG_TRACE("");
+#ifdef __WXMSW__    
+    delete wxHelpProvider::Set(NULL);
+#endif
+
     return wxApp::OnExit();
 }
 
