@@ -50,6 +50,9 @@ Batch::Batch(wxFrame* parent) : wxFrame(parent, wxID_ANY, _T("Batch"))
     //default flag settings
     deleteFiles = false;
     atEnd = DO_NOTHING;
+#if wxCHECK_VERSION(3,1,0)
+    m_resBlocker = NULL;
+#endif
     overwrite = true;
     verbose = false;
     autoremove = false;
@@ -66,6 +69,16 @@ Batch::Batch(wxFrame* parent) : wxFrame(parent, wxID_ANY, _T("Batch"))
 
 }
 
+Batch::~Batch()
+{
+#if wxCHECK_VERSION(3,1,0)
+    if (m_resBlocker != NULL)
+    {
+        delete m_resBlocker;
+    };
+#endif
+}
+
 void Batch::AddAppToBatch(wxString app)
 {
     Project* newApp = new Project(app);
@@ -198,6 +211,13 @@ void Batch::CancelBatch()
     {
         CancelProject(i);
     }
+#if wxCHECK_VERSION(3,1,0)
+    if (m_resBlocker != NULL)
+    {
+        delete m_resBlocker;
+        m_resBlocker = NULL;
+    };
+#endif
     m_running = false;
 }
 void Batch::CancelProject(int index)
@@ -525,6 +545,13 @@ void Batch::OnProcessTerminate(wxProcessEvent& event)
             {
                 SaveTemp();
                 m_running = false;
+#if wxCHECK_VERSION(3,1,0)
+                if (m_resBlocker != NULL)
+                {
+                    delete m_resBlocker;
+                    m_resBlocker = NULL;
+                };
+#endif
                 if(NoErrors())
                 {
                     wxCommandEvent e(EVT_INFORMATION,wxID_ANY);
@@ -544,67 +571,67 @@ void Batch::OnProcessTerminate(wxProcessEvent& event)
                         GetParent()->GetEventHandler()->AddPendingEvent(e);
                     };
                 };
-                if (atEnd != DO_NOTHING)	//after we are finished we turn off the computer if checked
+                switch (atEnd)
                 {
-                    switch (atEnd)
-                    {
-                        case CLOSE_PTBATCHERGUI:
-                            GetParent()->Close();
-                            break;
-                        case SHUTDOWN:
+                    case DO_NOTHING:
+                        // no action needed
+                        break;
+                    case CLOSE_PTBATCHERGUI:
+                        GetParent()->Close();
+                        break;
+                    case SHUTDOWN:
+                        {
+                            wxProgressDialog progress(_("Initializing shutdown..."), _("Shutting down..."), 49, this,
+                                wxPD_AUTO_HIDE | wxPD_SMOOTH | wxPD_APP_MODAL | wxPD_CAN_ABORT | wxPD_CAN_SKIP);
+                            progress.Fit();
+                            int i = 0;
+                            bool skip = false;
+                            while (progress.Update(i, _("Shutting down..."), &skip))
                             {
-                                wxProgressDialog progress(_("Initializing shutdown..."), _("Shutting down..."), 49, this,
-                                    wxPD_AUTO_HIDE | wxPD_SMOOTH | wxPD_APP_MODAL | wxPD_CAN_ABORT | wxPD_CAN_SKIP);
-                                progress.Fit();
-                                int i = 0;
-                                bool skip = false;
-                                while (progress.Update(i, _("Shutting down..."), &skip))
+                                if (skip || i == 50)
                                 {
-                                    if (skip || i == 50)
-                                    {
-                                        wxShutdown(wxSHUTDOWN_POWEROFF);
-                                    }
-                                    i++;
-    #if defined __WXMSW__
-                                    Sleep(200);
-    #else
-                                    sleep(200);
-    #endif
+                                    wxShutdown(wxSHUTDOWN_POWEROFF);
                                 }
-                                progress.Close();
-                            }
-                            break;
-                        case SUSPEND:
-                        case HIBERNATE:
-#ifdef __WXMSW__
-                            {
-                                wxString progressCaption(_("Prepare to hibernate..."));
-                                wxString progressLabel(_("Initializing hibernating..."));
-                                if (atEnd == SUSPEND)
-                                {
-                                    progressCaption = wxString(_("Prepare to suspend..."));
-                                    progressLabel = wxString(_("Initializing suspend mode..."));
-                                };
-                                wxProgressDialog progress(progressLabel, progressCaption, 49, this,
-                                    wxPD_AUTO_HIDE | wxPD_SMOOTH | wxPD_APP_MODAL | wxPD_CAN_ABORT | wxPD_CAN_SKIP);
-                                progress.Fit();
-                                int i = 0;
-                                bool skip = false;
-                                while (progress.Update(i, progressCaption, &skip))
-                                {
-                                    if (skip || i == 50)
-                                    {
-                                        SetSuspendState(atEnd==HIBERNATE, false, false);
-                                        break;
-                                    }
-                                    i++;
-                                    Sleep(200);
-                                }
-                                progress.Close();
-                            };
+                                i++;
+#if defined __WXMSW__
+                                Sleep(200);
+#else
+                                sleep(200);
 #endif
-                            break;
-                    };
+                            }
+                            progress.Close();
+                        }
+                        break;
+                    case SUSPEND:
+                    case HIBERNATE:
+#ifdef __WXMSW__
+                        {
+                            wxString progressCaption(_("Prepare to hibernate..."));
+                            wxString progressLabel(_("Initializing hibernating..."));
+                            if (atEnd == SUSPEND)
+                            {
+                                progressCaption = wxString(_("Prepare to suspend..."));
+                                progressLabel = wxString(_("Initializing suspend mode..."));
+                            };
+                            wxProgressDialog progress(progressLabel, progressCaption, 49, this,
+                                wxPD_AUTO_HIDE | wxPD_SMOOTH | wxPD_APP_MODAL | wxPD_CAN_ABORT | wxPD_CAN_SKIP);
+                            progress.Fit();
+                            int i = 0;
+                            bool skip = false;
+                            while (progress.Update(i, progressCaption, &skip))
+                            {
+                                if (skip || i == 50)
+                                {
+                                    SetSuspendState(atEnd==HIBERNATE, false, false);
+                                    break;
+                                }
+                                i++;
+                                Sleep(200);
+                            }
+                            progress.Close();
+                        };
+#endif
+                        break;
                 };
             }
             else
@@ -633,7 +660,7 @@ bool Batch::OnStitch(wxString scriptFile, wxString outname, int id)
     {
         wxString defaultdir = config->Read(wxT("/actualPath"),wxT(""));
         wxFileDialog dlg(0,
-                         _("Specify project source project file"),
+                         _("Specify project file"),
                          defaultdir, wxT(""),
                          _("Project files (*.pto)|*.pto|All files (*)|*"),
                          wxFD_OPEN, wxDefaultPosition);
@@ -811,6 +838,9 @@ void Batch::RunBatch()
         m_failedProjects.clear();
         ((wxFrame*)GetParent())->SetStatusText(_("Running batch..."));
         m_running = true;
+#if wxCHECK_VERSION(3,1,0)
+        m_resBlocker = new wxPowerResourceBlocker(wxPOWER_RESOURCE_SYSTEM, _("PTBatcherGUI is stitching"));
+#endif
         RunNextInBatch();
     }
     else
