@@ -19,8 +19,8 @@
  *  General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -34,14 +34,15 @@
 #include <sys/wait.h>
 #endif
 #include "RunStitchFrame.h"
+#if wxCHECK_VERSION(3,1,0)
+#include <wx/power.h>
+#endif
 
 #ifndef FRAMEARRAY
 #define FRAMEARRAY
 WX_DEFINE_ARRAY_PTR(RunStitchFrame*,FrameArray);
 #endif
 
-using namespace std;
-
 struct FailedProject
 {
     wxString project;
@@ -51,9 +52,16 @@ struct FailedProject
 class Batch : public wxFrame
 {
 public:
-    bool parallel;
+    enum EndTask
+    {
+        DO_NOTHING = 0,
+        CLOSE_PTBATCHERGUI = 1,
+        SHUTDOWN = 2,  // only implemented for GTK and Window in wxWidgets
+        SUSPEND = 3,   // only implemented for Windows
+        HIBERNATE = 4  // only implemented for Windows
+    };
     bool deleteFiles;
-    bool shutdown;
+    EndTask atEnd;
     bool overwrite;
     bool verbose;
     bool autostitch;
@@ -61,7 +69,9 @@ public:
     bool saveLog;
 
     /** Main constructor */
-    Batch(wxFrame* parent, wxString path);
+    explicit Batch(wxFrame* parent);
+    /** destructor */
+    ~Batch();
 
     /** Adds an application entry in the batch list */
     void  AddAppToBatch(wxString app);
@@ -173,15 +183,14 @@ private:
 
     //vector, which stores the failed projects and filename of saved logfile
     std::vector<FailedProject> m_failedProjects;
-
-    //external program config
-    PTPrograms progs;
-    AssistantPrograms progsAss;
+#if wxCHECK_VERSION(3,1,0)
+    wxPowerResourceBlocker* m_resBlocker;
+#endif
 
     DECLARE_EVENT_TABLE()
 };
 
-#if _WINDOWS && defined Hugin_shared
+#if defined _WIN32 && defined Hugin_shared
 DECLARE_LOCAL_EVENT_TYPE(EVT_BATCH_FAILED,-1)
 DECLARE_LOCAL_EVENT_TYPE(EVT_INFORMATION,-1)
 DECLARE_LOCAL_EVENT_TYPE(EVT_UPDATE_PARENT, -1)
