@@ -100,6 +100,7 @@ BEGIN_EVENT_TABLE(BatchFrame, wxFrame)
     EVT_MENU(XRCID("menu_open"),BatchFrame::OnButtonOpenBatch)
     EVT_MENU(XRCID("menu_save"),BatchFrame::OnButtonSaveBatch)
     EVT_MENU(XRCID("menu_clear"),BatchFrame::OnButtonClear)
+    EVT_MENU(XRCID("menu_tray"), BatchFrame::OnMinimizeTrayMenu)
     EVT_MENU(XRCID("menu_exit"),BatchFrame::OnUserExit)
     EVT_MENU(XRCID("menu_help"),BatchFrame::OnButtonHelp)
     EVT_BUTTON(XRCID("button_addcommand"),BatchFrame::OnButtonAddCommand)
@@ -155,39 +156,16 @@ BatchFrame::BatchFrame(wxLocale* locale, wxString xrc)
 
     // set the minimize icon
 #ifdef __WXMSW__
-    wxIcon myIcon(m_xrcPrefix + wxT("data/ptbatcher.ico"),wxBITMAP_TYPE_ICO);
+    m_iconNormal = wxIcon(m_xrcPrefix + wxT("data/ptbatcher.ico"), wxBITMAP_TYPE_ICO);
+    m_iconRunning = wxIcon(m_xrcPrefix + wxT("data/ptbatcher_running.ico"), wxBITMAP_TYPE_ICO);
+    m_iconPaused = wxIcon(m_xrcPrefix + wxT("data/ptbatcher_pause.ico"), wxBITMAP_TYPE_ICO);
 #else
-    wxIcon myIcon(m_xrcPrefix + wxT("data/ptbatcher.png"),wxBITMAP_TYPE_PNG);
+    m_iconNormal = wxIcon(m_xrcPrefix + wxT("data/ptbatcher.png"), wxBITMAP_TYPE_PNG);
+    m_iconRunning = wxIcon(m_xrcPrefix + wxT("data/ptbatcher_running.png"), wxBITMAP_TYPE_PNG);
+    m_iconPaused = wxIcon(m_xrcPrefix + wxT("data/ptbatcher_pause.png"), wxBITMAP_TYPE_PNG);
 #endif
-    SetIcon(myIcon);
+    SetIcon(m_iconNormal);
 
-#if defined __WXMSW__
-    //show tray icon only on windows
-    //because not all window manager on *nix provide a usable tray area
-#if wxCHECK_VERSION(2,9,0)
-    if(wxTaskBarIcon::IsAvailable())
-    {
-        m_tray=new BatchTaskBarIcon();
-        m_tray->SetIcon(myIcon,_("Hugin's Batch processor"));
-    }
-    else
-    {
-        m_tray=NULL;
-    };
-#else
-    m_tray=new BatchTaskBarIcon();
-    if(m_tray->IsOk())
-    {
-        m_tray->SetIcon(myIcon,_("Hugin's Batch processor"));
-    }
-    else
-    {
-        m_tray=NULL;
-    };
-#endif
-#else
-    m_tray=NULL;
-#endif
     m_batch = new Batch(this);
 #if wxCHECK_VERSION(2,9,4)
     if(wxGetKeyState(WXK_COMMAND))
@@ -258,6 +236,22 @@ BatchFrame::BatchFrame(wxLocale* locale, wxString xrc)
     //TO-DO: include a batch or project progress gauge?
     projListBox->Fill(m_batch);
     SetDropTarget(new BatchDropTarget());
+
+    m_tray = NULL;
+#if wxCHECK_VERSION(3,0,0)
+    if (wxTaskBarIcon::IsAvailable())
+    {
+        // minimize to tray is by default disabled
+        // activate only if task bar icon is available
+        GetMenuBar()->Enable(XRCID("menu_tray"), true);
+        bool minTray;
+        // tray icon is disabled by default 
+        wxConfigBase::Get()->Read(wxT("/BatchFrame/minimizeTray"), &minTray, false);
+        GetMenuBar()->Check(XRCID("menu_tray"), minTray);
+        UpdateTrayIcon(minTray);
+    }
+#endif
+
     UpdateTaskBarProgressBar();
 }
 
@@ -530,6 +524,10 @@ void BatchFrame::OnButtonCancel(wxCommandEvent& event)
     m_cancelled = true;
     m_batch->CancelBatch();
     SetStatusInformation(_("Batch stopped"),true);
+    if (m_tray)
+    {
+        m_tray->SetIcon(m_iconNormal, _("Hugin's Batch processor"));
+    };
 }
 
 void BatchFrame::OnButtonChangePrefix(wxCommandEvent& event)
@@ -629,7 +627,11 @@ void BatchFrame::OnButtonHelp(wxCommandEvent& event)
 {
     DEBUG_TRACE("");
 #ifdef __WXMSW__
+#if wxCHECK_VERSION(3,1,1)
     GetHelpController().DisplaySection(wxT("Hugin_Batch_Processor.html"));
+#else
+    GetHelpController().DisplayHelpPage(wxT("Hugin_Batch_Processor.html"));
+#endif
 #else
     if (m_help == 0)
     {
@@ -731,7 +733,7 @@ void BatchFrame::OnButtonOpenWithHugin(wxCommandEvent& event)
     {
         //ask user if he/she wants to load an empty project
         wxMessageDialog message(this,_("No project selected. Open Hugin without project?"),
-#ifdef _WINDOWS
+#ifdef _WIN32
                                 _("PTBatcherGUI"),
 #else
                                 wxT(""),
@@ -757,18 +759,27 @@ void BatchFrame::OnButtonPause(wxCommandEvent& event)
             m_batch->PauseBatch();
             GetToolBar()->ToggleTool(XRCID("tool_pause"),true);
             SetStatusInformation(_("Batch paused"),true);
+            if (m_tray)
+            {
+                m_tray->SetIcon(m_iconPaused, _("Pausing processing Hugin's batch queue"));
+            };
         }
         else
         {
             m_batch->PauseBatch();
             GetToolBar()->ToggleTool(XRCID("tool_pause"),false);
             SetStatusInformation(_("Continuing batch..."),true);
+            if (m_tray)
+            {
+                m_tray->SetIcon(m_iconRunning, _("Processing Hugin's batch queue"));
+            };
         }
     }
     else //if no projects are running, we deactivate the button
     {
         GetToolBar()->ToggleTool(XRCID("tool_pause"),false);
     }
+    UpdateTaskBarProgressBar();
 }
 
 void BatchFrame::OnButtonRemoveComplete(wxCommandEvent& event)
@@ -777,7 +788,7 @@ void BatchFrame::OnButtonRemoveComplete(wxCommandEvent& event)
     if(!m_batch->NoErrors())
     {
         wxMessageDialog message(this,_("There are failed projects in the list.\nRemove them too?"),
-#ifdef _WINDOWS
+#ifdef _WIN32
                                 _("PTBatcherGUI"),
 #else
                                 wxT(""),
@@ -809,7 +820,7 @@ void BatchFrame::OnButtonRemoveFromList(wxCommandEvent& event)
         if(m_batch->GetStatus(selIndex)==Project::RUNNING || m_batch->GetStatus(selIndex)==Project::PAUSED)
         {
             wxMessageDialog message(this, _("Cannot remove project in progress.\nDo you want to cancel it?"),
-#ifdef _WINDOWS
+#ifdef _WIN32
                                     _("PTBatcherGUI"),
 #else
                                     wxT(""),
@@ -844,7 +855,7 @@ void BatchFrame::OnButtonReset(wxCommandEvent& event)
         if(m_batch->GetStatus(selIndex)==Project::RUNNING || m_batch->GetStatus(selIndex)==Project::PAUSED)
         {
             wxMessageDialog message(this, _("Cannot reset project in progress.\nDo you want to cancel it?"),
-#ifdef _WINDOWS
+#ifdef _WIN32
                                     _("PTBatcherGUI"),
 #else
                                     wxT(""),
@@ -873,7 +884,7 @@ void BatchFrame::OnButtonResetAll(wxCommandEvent& event)
     if(m_batch->GetRunningCount()!=0)
     {
         wxMessageDialog message(this, _("Cannot reset projects in progress.\nDo you want to cancel the batch?"),
-#ifdef _WINDOWS
+#ifdef _WIN32
                                 _("PTBatcherGUI"),
 #else
                                 wxT(""),
@@ -1139,6 +1150,25 @@ void BatchFrame::OnCheckSaveLog(wxCommandEvent& event)
 
 void BatchFrame::OnClose(wxCloseEvent& event)
 {
+    // check size of batch queue
+    if (m_batch->GetProjectCount() > 500)
+    {
+        wxMessageDialog message(this, _("The batch queue contains many items.\nThis can have negative effects on performance.\nShould the batch queue be cleared now?"),
+#ifdef __WXMSW__
+            _("PTBatcherGUI"),
+#else
+            wxT(""),
+#endif
+            wxYES_NO | wxICON_INFORMATION);
+#if wxCHECK_VERSION(3,0,0)
+        message.SetYesNoLabels(_("Clear batch queue now"), _("Keep batch queue"));
+#endif
+        if (message.ShowModal() == wxID_YES)
+        {
+            m_batch->ClearBatch();
+            m_batch->SaveTemp();
+        };
+    };
     //save windows position
     wxConfigBase* config=wxConfigBase::Get();
     if(IsMaximized())
@@ -1191,6 +1221,10 @@ void BatchFrame::RunBatch()
     if(!IsRunning())
     {
         SetStatusInformation(_("Starting batch"),true);
+        if (m_tray)
+        {
+            m_tray->SetIcon(m_iconRunning, _("Processing Hugin's batch queue"));
+        };
     }
     m_batch->RunBatch();
 }
@@ -1224,6 +1258,10 @@ void BatchFrame::OnProcessTerminate(wxProcessEvent& event)
     if(m_batch->GetRunningCount()==1)
     {
         GetToolBar()->ToggleTool(XRCID("tool_pause"),false);
+        if (m_tray)
+        {
+            m_tray->SetIcon(m_iconNormal, _("Hugin's Batch processor"));
+        };
     }
     event.Skip();
 }
@@ -1256,7 +1294,11 @@ void BatchFrame::OnBatchFailed(wxCommandEvent& event)
 {
     if(m_batch->GetFailedProjectsCount()>0)
     {
-        FailedProjectsDialog failedProjects_dlg(this,m_batch,m_xrcPrefix);
+        if (m_tray)
+        {
+            m_tray->SetIcon(m_iconNormal, _("Hugin's Batch processor"));
+        };
+        FailedProjectsDialog failedProjects_dlg(this, m_batch, m_xrcPrefix);
         failedProjects_dlg.ShowModal();
     };
 };
@@ -1264,6 +1306,11 @@ void BatchFrame::OnBatchFailed(wxCommandEvent& event)
 void BatchFrame::OnBatchInformation(wxCommandEvent& e)
 {
     SetStatusInformation(e.GetString(),true);
+    if (m_tray && e.GetInt() == 1)
+    {
+        // batch finished, reset icon in task bar
+        m_tray->SetIcon(m_iconNormal, _("Hugin's Batch processor"));
+    };
 };
 
 void BatchFrame::SetStatusInformation(wxString status,bool showBalloon)
@@ -1309,7 +1356,7 @@ void BatchFrame::UpdateTaskBarProgressBar()
             else
             {
                 taskBarButton->SetProgressRange(100);
-                taskBarButton->SetProgressState(wxTASKBAR_BUTTON_NORMAL);
+                taskBarButton->SetProgressState(m_batch->IsPaused() ? wxTASKBAR_BUTTON_PAUSED : wxTASKBAR_BUTTON_NORMAL);
                 taskBarButton->SetProgressValue(m_progStatusBar->GetProgress());
             };
         };
@@ -1381,3 +1428,47 @@ void BatchFrame::OnRefillListBox(wxCommandEvent& event)
         };
     };
 };
+
+void BatchFrame::OnMinimizeTrayMenu(wxCommandEvent& event)
+{
+    UpdateTrayIcon(event.IsChecked());
+    wxConfigBase::Get()->Write(wxT("/BatchFrame/minimizeTray"), event.IsChecked());
+}
+
+void BatchFrame::UpdateTrayIcon(const bool createTrayIcon)
+{
+    if (createTrayIcon)
+    {
+        // create tray icon only if it not exists
+        if (m_tray)
+        {
+            delete m_tray;
+            m_tray = NULL;
+        }
+        m_tray = new BatchTaskBarIcon();
+        if (m_batch->IsRunning())
+        {
+            m_tray->SetIcon(m_iconRunning, _("Processing Hugin's batch queue"));
+        }
+        else
+        {
+            if (m_batch->IsPaused())
+            {
+                m_tray->SetIcon(m_iconPaused, _("Pausing processing Hugin's batch queue"));
+            }
+            else
+            {
+                m_tray->SetIcon(m_iconNormal, _("Hugin's Batch processor"));
+            }
+        }
+    }
+    else
+    {
+        // destroy tray icon
+        if (m_tray)
+        {
+            delete m_tray;
+            m_tray = NULL;
+        }
+    }
+}
