@@ -18,8 +18,8 @@
  *  Lesser General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -38,10 +38,11 @@ namespace HuginBase {
 void CalculateCPStatisticsError::calcCtrlPntsErrorStats(const PanoramaData& pano,
                                                         double & min, double & max, double & mean,
                                                         double & var,
-                                                        const int& imgNr)
+                                                        const int& imgNr,
+                                                        const bool onlyActive)
 {
     const CPVector& cps = pano.getCtrlPoints();
-    
+    const UIntSet activeImgs(pano.getActiveImages());
     max = 0;
     min = 1000000;
     mean = 0;
@@ -54,6 +55,10 @@ void CalculateCPStatisticsError::calcCtrlPntsErrorStats(const PanoramaData& pano
         {
             continue;
         }
+        if (onlyActive && (!set_contains(activeImgs, it->image1Nr) || !set_contains(activeImgs, it->image2Nr)))
+        {
+            continue;
+        };
         n++;
         double x = (*it).error;
         double delta = x - mean;
