@@ -26,19 +26,16 @@
 #include "CalculateFOV.h"
 
 #include <algorithm>
-#include <vigra/impex.hxx>
 #include <vigra/copyimage.hxx>
 #include <nona/RemappedPanoImage.h>
 
 namespace HuginBase {
 
-using namespace hugin_utils;
-
-FDiff2D CalculateFOV::calcFOV(const PanoramaData& panorama)
+hugin_utils::FDiff2D CalculateFOV::calcFOV(const PanoramaData& panorama)
 {
     if (panorama.getNrOfImages() == 0) {
         // no change
-        return FDiff2D(panorama.getOptions().getHFOV(), panorama.getOptions().getVFOV());
+        return hugin_utils::FDiff2D(panorama.getOptions().getHFOV(), panorama.getOptions().getVFOV());
     }
 
     vigra::Size2D panoSize(360*2,180*2);
@@ -71,12 +68,10 @@ FDiff2D CalculateFOV::calcFOV(const PanoramaData& panorama)
                                                 vigra_ext::srcMask(remapped)),
                             vigra_ext::applyRect(remapped.boundingBox(),
                                                 destImage(panoAlpha)));
-        //        vigra::ImageExportInfo imge2("c:/hugin_calcfov_alpha.png");
-        //        exportImage(vigra::srcImageRange(panoAlpha), imge2);
         }
 
     // get field of view
-    FDiff2D ul,lr;
+    hugin_utils::FDiff2D ul, lr;
     bool found = false;
     ul.x = DBL_MAX;
     ul.y = DBL_MAX;
@@ -107,7 +102,7 @@ FDiff2D CalculateFOV::calcFOV(const PanoramaData& panorama)
     }
     if (!found) {
         // if nothing found, return current fov
-        return FDiff2D(panorama.getOptions().getHFOV(), panorama.getOptions().getVFOV());
+        return hugin_utils::FDiff2D(panorama.getOptions().getHFOV(), panorama.getOptions().getVFOV());
     }
     ul=ul/2.0;
     lr=lr/2.0;
@@ -115,7 +110,7 @@ FDiff2D CalculateFOV::calcFOV(const PanoramaData& panorama)
     ul.y = ul.y - 90;
     lr.x = lr.x - 180;
     lr.y = lr.y - 90;
-    FDiff2D fov (2*std::max(fabs(ul.x), fabs(lr.x)), 2*std::max(fabs(ul.y), fabs(lr.y)));
+    hugin_utils::FDiff2D fov(2 * std::max(fabs(ul.x), fabs(lr.x)), 2 * std::max(fabs(ul.y), fabs(lr.y)));
     if(fov.x<40)
     {
         fov.x+=1;
