@@ -42,9 +42,10 @@ class IMPEX ProgressDisplay
 {
 protected:
     /** constructor */
-    ProgressDisplay(int maximum=0) : m_canceled(false), m_maximum(maximum), m_progress(0) {};
-
+    explicit ProgressDisplay(int maximum=0) : m_canceled(false), m_maximum(maximum), m_progress(0) {};
 public:
+    /* virtual destructor */
+    virtual ~ProgressDisplay() {};
     /** sets the message to given string */
     void setMessage(const std::string& message, const std::string& filename="");
     /** call when a task has finished and the status message should be cleared */
@@ -89,7 +90,7 @@ class IMPEX StreamProgressDisplay : public ProgressDisplay
 {
     public:
         /** constructor, connect with given outputstream */
-        StreamProgressDisplay(std::ostream & o) : ProgressDisplay(), m_stream(o) {};
+        explicit StreamProgressDisplay(std::ostream & o) : ProgressDisplay(), m_stream(o) {};
         /** update the display, print the message to stream */
         virtual void updateProgressDisplay();
     protected:
