@@ -28,11 +28,7 @@
 
 #include <iostream>
 #include "hugin_config.h"
-#ifdef USE_CXX11_THREAD
 #include <thread>
-#else
-#include <boost/thread/thread.hpp>
-#endif
 #include <vigra/inspectimage.hxx>
 #include <vigra/accessor.hxx>
 #include <vigra/functorexpression.hxx>
@@ -46,10 +42,6 @@
 
 namespace HuginBase {
     
-using namespace std;
-using namespace vigra::functor;
-
-
 template <class T1>
 class GetRange
 {
@@ -133,12 +125,12 @@ ImageCache * ImageCache::instance = NULL;
 
 void ImageCache::removeImage(const std::string & filename)
 {
-    map<string, EntryPtr>::iterator it = images.find(filename);
+    std::map<std::string, EntryPtr>::iterator it = images.find(filename);
     if (it != images.end()) {
         images.erase(it);
     }
 
-    string sfilename = filename + string("_small");
+    std::string sfilename = filename + std::string("_small");
     it = images.find(sfilename);
     if (it != images.end()) {
         images.erase(it);
@@ -149,7 +141,7 @@ void ImageCache::removeImage(const std::string & filename)
     do {
         // found. xyz
         PyramidKey key(filename,level);
-        map<string, vigra::BImage*>::iterator it = pyrImages.find(key.toString());
+        std::map<std::string, vigra::BImage*>::iterator it = pyrImages.find(key.toString());
         found = (it != pyrImages.end());
         if (found) {
             delete it->second;
@@ -170,7 +162,7 @@ void ImageCache::flush()
 {
     images.clear();
 
-    for (map<string, vigra::BImage*>::iterator it = pyrImages.begin();
+    for (std::map<std::string, vigra::BImage*>::iterator it = pyrImages.begin();
          it != pyrImages.end();
          ++it)
     {
@@ -181,66 +173,68 @@ void ImageCache::flush()
 
 void ImageCache::softFlush()
 {
-    if(upperBound==0l)
-        upperBound = 100 * 1024 * 1024l;
-    long purgeToSize = long(0.75 * upperBound);
+    if (upperBound == 0ull)
+    {
+        upperBound = 100 * 1024 * 1024ull;
+    };
+    const unsigned long long purgeToSize = static_cast<unsigned long long>(0.75 * upperBound);
 
     // calculate used memory
-    long imgMem = 0;
+    unsigned long long imgMem = 0;
 
     std::map<std::string, EntryPtr>::iterator imgIt;
     for(imgIt=images.begin(); imgIt != images.end(); ++imgIt) {
 #ifdef DEBUG
-        cout << "Image: " << imgIt->first << std::endl;
-        cout << "CacheEntry: " << imgIt->second.use_count() << "last access: " << imgIt->second->lastAccess;
+        std::cout << "Image: " << imgIt->first << std::endl;
+        std::cout << "CacheEntry: " << imgIt->second.use_count() << "last access: " << imgIt->second->lastAccess;
 #endif
         if (imgIt->second->image8) {
             imgMem += imgIt->second->image8->width() * imgIt->second->image8->height() * 3;
 #ifdef DEBUG
-            cout << " 8bit: " << imgIt->second->image8.use_count();
+            std::cout << " 8bit: " << imgIt->second->image8.use_count();
 #endif
         }
         if (imgIt->second->image16) {
             imgMem += imgIt->second->image16->width() * imgIt->second->image16->height() * 3*2;
 #ifdef DEBUG
-            cout << " 16bit: " << imgIt->second->image8.use_count();
+            std::cout << " 16bit: " << imgIt->second->image8.use_count();
 #endif
         }
         if (imgIt->second->imageFloat) {
             imgMem += imgIt->second->imageFloat->width() * imgIt->second->imageFloat->height() * 3 * 4;
 #ifdef DEBUG
-            cout << " float: " << imgIt->second->imageFloat.use_count() ;
+            std::cout << " float: " << imgIt->second->imageFloat.use_count() ;
 #endif
         }
         if (imgIt->second->mask) {
             imgMem += imgIt->second->mask->width() * imgIt->second->mask->height();
 #ifdef DEBUG
-            cout << " mask: " << imgIt->second->mask.use_count() << std:: endl;
+            std::cout << " mask: " << imgIt->second->mask.use_count() << std::endl;
 #endif
         }
     }
 
-    long pyrMem = 0;
+    unsigned long long pyrMem = 0;
     std::map<std::string, vigra::BImage*>::iterator pyrIt;
     for(pyrIt=pyrImages.begin(); pyrIt != pyrImages.end(); ++pyrIt) {
         pyrMem += pyrIt->second->width() * pyrIt->second->height();
     }
 
-    long usedMem = imgMem + pyrMem;
+    const unsigned long long usedMem = imgMem + pyrMem;
 
     DEBUG_DEBUG("total: " << (usedMem>>20) << " MB upper bound: " << (purgeToSize>>20) << " MB");
     if (usedMem > upperBound) 
     {
         // we need to remove images.
-        long purgeAmount = usedMem - purgeToSize;
-        long purgedMem = 0;
+        const unsigned long long purgeAmount = usedMem - purgeToSize;
+        unsigned long long purgedMem = 0;
         // remove images from cache, first the grey level image,
         // then the full size images
 
         // use least recently uses strategy.
         // sort images by their access time
         std::map<int,std::string> accessMap;
-        for (map<string, EntryPtr>::iterator it = images.begin();
+        for (std::map<std::string, EntryPtr>::iterator it = images.begin();
              it != images.end();
              ++it)
         {
@@ -256,7 +250,7 @@ void ImageCache::softFlush()
         }
         while (purgeAmount > purgedMem) {
             bool deleted = false;
-            if (pyrImages.size() > 0) {
+            if (!pyrImages.empty()) {
                 vigra::BImage * imgPtr = (*(pyrImages.begin())).second;
                 purgedMem += imgPtr->width() * imgPtr->height();
                 delete imgPtr;
@@ -264,7 +258,7 @@ void ImageCache::softFlush()
                 deleted = true;
             } else if (!accessMap.empty()) {
                 std::map<int,std::string>::iterator accIt = accessMap.begin();
-                map<string, EntryPtr>::iterator it = images.find(accIt->second);
+                std::map<std::string, EntryPtr>::iterator it = images.find(accIt->second);
                 // check for uniqueness.
                 if (it != images.end()) {
                     DEBUG_DEBUG("soft flush: removing image: " << it->first);
@@ -389,8 +383,6 @@ void ImageCache::importAndConvertImage(const vigra::ImageImportInfo & info,
                                        vigra::pair<DestIterator, DestAccessor> dest,
                                        const std::string & type)
 {
-    typedef typename DestAccessor::value_type DestPixelType;
-
     if (type == "FLOAT" || type == "DOUBLE" ) {
         // import image as it is
         vigra::importImage(info, dest);
@@ -398,94 +390,12 @@ void ImageCache::importAndConvertImage(const vigra::ImageImportInfo & info,
         vigra::importImage(info, dest);
         // integer image.. scale to 0 .. 1
         double scale = 1.0/vigra_ext::LUTTraits<SrcPixelType>::max();
-//        DestPixelType factor(scale);
-        vigra_ext::Multiply<double> f(scale);
-        transformImage(dest.first, dest.first+ vigra::Diff2D(info.width(), info.height()), dest.second,
-                       dest.first, dest.second,
-                       Arg1()*Param(scale));
+        vigra::transformImage(dest.first, dest.first + vigra::Diff2D(info.width(), info.height()), dest.second,
+            dest.first, dest.second,
+            vigra::functor::Arg1()*vigra::functor::Param(scale));
     }
 }
 
-#if 0
-
-template <class SrcPixelType,
-          class DestIterator, class DestAccessor>
-void ImageCache::importAndConvertGrayImage(const ImageImportInfo & info,
-                                           vigra::pair<DestIterator, DestAccessor> dest,
-                                           wxString type)
-
-{
-    typedef typename DestAccessor::value_type DestPixelType;
-    typedef typename DestPixelType::value_type DestComponentType;
-    typedef SrcPixelType SrcComponentType;
-
-    // load image into temporary buffer.
-    BasicImage<SrcPixelType> tmp(info.width(), info.height());
-    vigra::importImage(info, destImage(tmp));
-
-    SrcComponentType min,max;
-
-    int range = wxConfigBase::Get()->Read(wxT("/ImageCache/Range"), HUGIN_IMGCACHE_RANGE);
-    if (range == 0) {
-        double t;
-        wxConfigBase::Get()->Read(wxT("/ImageCache/") + type + wxT("/min"), &t, double(GetRange<SrcComponentType>::min()));
-        min = SrcComponentType(t);
-        wxConfigBase::Get()->Read(wxT("/ImageCache/") + type + wxT("/max"), &t, double(GetRange<SrcComponentType>::max()));
-        max = SrcComponentType(t);
-    } else if (range == 1) {
-        vigra::FindMinMax<SrcComponentType> minmax;   // init functor
-        vigra::inspectImage(srcImageRange(tmp),
-                            minmax);
-        min = minmax.min;
-        max = minmax.max;
-    } else{
-        vigra_fail("Unknown image import range mode");
-    }
-
-    int mapping = wxConfigBase::Get()->Read(wxT("/ImageCache/Mapping"), HUGIN_IMGCACHE_MAPPING);
-    applyMapping(srcImageRange(tmp), dest, min, max, mapping);
-}
-
-template <class SrcPixelType,
-          class DestIterator, class DestAccessor>
-void ImageCache::importAndConvertGrayAlphaImage(const ImageImportInfo & info,
-                                                vigra::pair<DestIterator, DestAccessor> dest,
-                                                wxString type)
-{
-    typedef typename DestAccessor::value_type DestPixelType;
-    typedef typename DestPixelType::value_type DestComponentType;
-    typedef SrcPixelType SrcComponentType;
-
-    // load image into temporary buffer.
-    BasicImage<SrcPixelType> tmp(info.width(), info.height());
-    BImage mask(info.width(), info.height());
-    vigra::importImageAlpha(info, destImage(tmp), destImage(mask));
-
-    SrcComponentType min,max;
-
-    int range = wxConfigBase::Get()->Read(wxT("/ImageCache/Range"), HUGIN_IMGCACHE_RANGE);
-    if (range == 0) {
-        double t;
-        wxConfigBase::Get()->Read(wxT("/ImageCache/") + type + wxT("/min"), &t, double(GetRange<SrcComponentType>::min()));
-        min = SrcComponentType(t);
-        wxConfigBase::Get()->Read(wxT("/ImageCache/") + type + wxT("/max"), &t, double(GetRange<SrcComponentType>::max()));
-        max = SrcComponentType(t);
-    } else if (range == 1) {
-        vigra::FindMinMax<SrcComponentType> minmax;   // init functor
-        vigra::inspectImage(srcImageRange(tmp),
-                            minmax);
-        min = minmax.min;
-        max = minmax.max;
-    } else{
-        vigra_fail("Unknown image import range mode");
-    }
-
-    int mapping = wxConfigBase::Get()->Read(wxT("/ImageCache/Mapping"), HUGIN_IMGCACHE_MAPPING);
-    applyMapping(srcImageRange(tmp), dest, min, max, mapping);
-}
-
-#endif
-
 template <class SrcPixelType,
           class DestIterator, class DestAccessor,
           class MaskIterator, class MaskAccessor>
@@ -501,9 +411,9 @@ void ImageCache::importAndConvertAlphaImage(const vigra::ImageImportInfo & info,
         // integer image.. scale to 0 .. 1
         vigra::importImageAlpha(info, dest, mask);
         double scale = 1.0/vigra_ext::LUTTraits<SrcPixelType>::max();
-        transformImage(dest.first, dest.first+ vigra::Diff2D(info.width(), info.height()),  dest.second, 
-                       dest.first, dest.second,
-                       Arg1()*Param(scale));
+        vigra::transformImage(dest.first, dest.first + vigra::Diff2D(info.width(), info.height()), dest.second,
+            dest.first, dest.second,
+            vigra::functor::Arg1()*vigra::functor::Param(scale));
     }
 }
 
@@ -547,10 +457,15 @@ ImageCache::EntryPtr ImageCache::loadImageSafely(const std::string & filename)
     ImageCacheRGB16Ptr img16(new vigra::UInt16RGBImage);
     ImageCacheRGBFloatPtr imgFloat(new vigra::FRGBImage);
     ImageCache8Ptr mask(new vigra::BImage);
+    ImageCacheICCProfile iccProfile(new vigra::ImageImportInfo::ICCProfile);
 
     try {
         vigra::ImageImportInfo info(filename.c_str());
 
+        if (!info.getICCProfile().empty())
+        {
+            *iccProfile = info.getICCProfile();
+        };
         int bands = info.numBands();
         int extraBands = info.numExtraBands();
         const char * pixelType = info.getPixelType();
@@ -705,7 +620,7 @@ ImageCache::EntryPtr ImageCache::loadImageSafely(const std::string & filename)
        return EntryPtr();
     }
 
-    return EntryPtr(new Entry(img8, img16, imgFloat, mask, pixelTypeStr));
+    return EntryPtr(new Entry(img8, img16, imgFloat, mask, iccProfile, pixelTypeStr));
 }
 
 ImageCache::EntryPtr ImageCache::getImageIfAvailable(const std::string & filename)
@@ -728,7 +643,7 @@ ImageCache::EntryPtr ImageCache::getSmallImage(const std::string & filename)
     softFlush();
     std::map<std::string, EntryPtr>::iterator it;
     // "_small" is only used internally
-    string name = filename + string(":small");
+    std::string name = filename + std::string(":small");
     it = images.find(name);
     if (it != images.end()) {
         return it->second;
@@ -779,6 +694,11 @@ ImageCache::EntryPtr ImageCache::loadSmallImageSafely(EntryPtr entry)
     }
     EntryPtr e(new Entry);
     e->origType = entry->origType;
+    // also copy icc profile
+    if (!entry->iccProfile->empty())
+    {
+        *(e->iccProfile) = *(entry->iccProfile);
+    };
     // TODO: fix bug with mask reduction
     vigra::BImage fullsizeMask = *(entry->mask);
     if (entry->imageFloat->width() != 0 ) {
@@ -814,7 +734,7 @@ ImageCache::EntryPtr ImageCache::getSmallImageIfAvailable(const std::string & fi
     softFlush();
     std::map<std::string, EntryPtr>::iterator it;
     // "_small" is only used internally
-    string name = filename + string(":small");
+    std::string name = filename + std::string(":small");
     it = images.find(name);
     if (it != images.end()) {
         return it->second;
@@ -945,12 +865,8 @@ void ImageCache::spawnAsyncThread()
         {
             DEBUG_DEBUG("Not staring a thread to load an image, since no images are wanted.");
         } else {
-#ifdef USE_CXX11_THREAD
             std::thread thread(loadSafely, it->second, EntryPtr());
             thread.detach();
-#else
-            boost::thread(loadSafely, it->second, EntryPtr());
-#endif
         }
     } else {
         // got a small image request, check if its larger version has loaded.
@@ -960,20 +876,12 @@ void ImageCache::spawnAsyncThread()
         {
             // the larger one is needed to generate it.
             RequestPtr request(new Request(filename, false));
-#ifdef USE_CXX11_THREAD
             std::thread thread(loadSafely, request, EntryPtr());
             thread.detach();
-#else
-            boost::thread(loadSafely, request, EntryPtr());
-#endif
         } else {
             // we have the large image.
-#ifdef USE_CXX11_THREAD
             std::thread thread(loadSafely, it->second, large);
             thread.detach();
-#else
-            boost::thread(loadSafely, it->second, large);
-#endif
         }
     }
     // thread should be processing the image asynchronously now.
