@@ -452,6 +452,7 @@ bool PanoDetector::AnalyzeImage(ImgData& ioImgInfo, const PanoDetector& iPanoDet
                             final_img = new vigra::DImage(scaled->size());
                             vigra::copyImage(vigra::srcImageRange(*scaled, vigra::RGBToGrayAccessor<vigra::RGBValue<vigra::UInt8> >()),
                                 vigra::destImage(*final_img));
+                            delete scaled;
                         };
                         break;
                     case vigra::ImageImportInfo::UINT16:
@@ -521,6 +522,7 @@ bool PanoDetector::AnalyzeImage(ImgData& ioImgInfo, const PanoDetector& iPanoDet
                             // keypoint finder expext 0..255 range
                             vigra::transformImage(vigra::srcImageRange(*scaled, vigra::RGBToGrayAccessor<vigra::RGBValue<vigra::UInt16> >()),
                                 vigra::destImage(*final_img), vigra::functor::Arg1() / vigra::functor::Param(255.0));
+                            delete scaled;
                         };
                         break;
                     default:
@@ -541,7 +543,8 @@ bool PanoDetector::AnalyzeImage(ImgData& ioImgInfo, const PanoDetector& iPanoDet
                             // range adaption
                             double minVal = 0;
                             double maxVal;
-                            if (aImageInfo.getPixelType() == std::string("FLOAT") || aImageInfo.getPixelType() == std::string("DOUBLE"))
+                            const bool isDouble = aImageInfo.getPixelType() == std::string("FLOAT") || aImageInfo.getPixelType() == std::string("DOUBLE");
+                            if (isDouble)
                             {
                                 vigra::FindMinMax<float> minmax;   // init functor
                                 vigra::inspectImage(vigra::srcImageRange(*rgbImage, vigra::RGBToGrayAccessor<vigra::RGBValue<double> >()), minmax);
@@ -559,7 +562,13 @@ bool PanoDetector::AnalyzeImage(ImgData& ioImgInfo, const PanoDetector& iPanoDet
                                 TRACE_IMG("Rescale range...");
                                 if (!range255)
                                 {
-                                    vigra_ext::applyMapping(vigra::srcImageRange(*rgbImage), vigra::destImage(*rgbImage), minVal, maxVal, 0);
+                                    int mapping = 0;
+                                    if (isDouble && iPanoDetector._panoramaInfoCopy.getImage(ioImgInfo._number).getResponseType() == HuginBase::BaseSrcPanoImage::RESPONSE_LINEAR)
+                                    {
+                                        // switch to log mapping for double/float images with linear response type
+                                        mapping = 1;
+                                    };
+                                    vigra_ext::applyMapping(vigra::srcImageRange(*rgbImage), vigra::destImage(*rgbImage), minVal, maxVal, mapping);
                                 };
                                 range255 = true;
                             }
@@ -634,6 +643,7 @@ bool PanoDetector::AnalyzeImage(ImgData& ioImgInfo, const PanoDetector& iPanoDet
                                 vigra::transformImage(vigra::srcImageRange(*scaled, vigra::RGBToGrayAccessor<vigra::RGBValue<double> >()),
                                     vigra::destImage(*final_img), vigra::functor::Arg1() * vigra::functor::Param(255.0));
                             };
+                            delete scaled;
                         };
                         break;
                 };
@@ -940,6 +950,8 @@ bool PanoDetector::FindMatchesInPair(MatchData& ioMatchData, const PanoDetector&
         ioMatchData._matches.push_back(lfeat::PointMatchPtr( new lfeat::PointMatch(aP.first, ioMatchData._i2->_kp[aP.second])));
     }
 
+    delete[] indices.ptr();
+    delete[] dists.ptr();
     TRACE_PAIR("Found " << ioMatchData._matches.size() << " matches.");
     return true;
 }
