@@ -36,18 +36,11 @@
 #include <vigra_ext/impexalpha.hxx>
 #include <algorithms/point_sampler/PointSampler.h>
 
-using namespace std;
-using namespace vigra;
-using namespace vigra_ext;
-using namespace AppBase;
-using namespace HuginBase;
-
 template<class ImageType>
 std::vector<ImageType *> loadImagesPyr(std::vector<std::string> files, int pyrLevel, int verbose)
 {
-    typedef typename ImageType::value_type PixelType;
     std::vector<ImageType *> srcImgs(files.size());
-#ifdef _WINDOWS
+#ifdef _WIN32
     // init vigra codec manager before threaded section
     // otherwise there could be sometimes race conditions
     // which results in exceptions
@@ -87,7 +80,7 @@ std::vector<ImageType *> loadImagesPyr(std::vector<std::string> files, int pyrLe
                 if (verbose > 0) {
                     buf << tImg->size().x << "x" << tImg->size().y << "  " << std::flush;
                 }
-                reduceToNextLevel(*tImg, *tImg2);
+                vigra_ext::reduceToNextLevel(*tImg, *tImg2);
                 swap = tImg;
                 tImg = tImg2;
                 tImg2 = swap;
@@ -112,7 +105,7 @@ std::vector<ImageType *> loadImagesPyr(std::vector<std::string> files, int pyrLe
 
 
 // needs 2.0 progress steps
-void loadImgsAndExtractPoints(Panorama pano, int nPoints, int pyrLevel, bool randomPoints, AppBase::ProgressDisplay& progress, std::vector<vigra_ext::PointPairRGB> & points, int verbose)
+void loadImgsAndExtractPoints(HuginBase::Panorama pano, int nPoints, int pyrLevel, bool randomPoints, AppBase::ProgressDisplay& progress, std::vector<vigra_ext::PointPairRGB> & points, int verbose)
 {
     // extract file names
     std::vector<std::string> files;
@@ -126,8 +119,8 @@ void loadImgsAndExtractPoints(Panorama pano, int nPoints, int pyrLevel, bool ran
     
     progress.setMessage("Sampling points");
     if(randomPoints)
-        points = RandomPointSampler(pano, &progress, images, nPoints).execute().getResultPoints();
+        points = HuginBase::RandomPointSampler(pano, &progress, images, nPoints).execute().getResultPoints();
     else
-        points = AllPointSampler(pano, &progress, images, nPoints).execute().getResultPoints();
+        points = HuginBase::AllPointSampler(pano, &progress, images, nPoints).execute().getResultPoints();
     progress.taskFinished();
 }
