@@ -29,7 +29,7 @@
 
 #include <fstream>
 #include <sstream>
-#ifdef WIN32
+#ifdef _WIN32
 #include <getopt.h>
 #else
 #include <unistd.h>
@@ -49,42 +49,37 @@
 #include <panodata/StandardImageVariableGroups.h>
 #include "ExtractPoints.h"
 
-using namespace std;
-using namespace hugin_utils;
-using namespace HuginBase;
-using namespace AppBase;
-
 static void usage(const char* name)
 {
-    cerr << name << ": optimize image positions" << endl
-         << "autooptimiser version " << hugin_utils::GetHuginVersion() << endl
-         << endl
-         << "Usage:  " << name << " [options] input.pto" << endl
-         << "   To read a project from stdio, specify - as input file." << endl
-         << endl
-         << "  Options:" << endl
-         << "     -o file.pto  output file. If omitted, stdout is used." << endl
-         << endl
+    std::cerr << name << ": optimize image positions" << std::endl
+        << "autooptimiser version " << hugin_utils::GetHuginVersion() << std::endl
+        << std::endl
+        << "Usage:  " << name << " [options] input.pto" << std::endl
+        << "   To read a project from stdio, specify - as input file." << std::endl
+        << std::endl
+        << "  Options:" << std::endl
+        << "     -o file.pto  output file. If omitted, stdout is used." << std::endl
+        << std::endl
          << "    Optimisation options (if not specified, no optimisation takes place)" << std::endl
-         << "     -a       auto align mode, includes various optimisation stages, depending" << endl
-         << "               on the amount and distribution of the control points" << endl
-         << "     -p       pairwise optimisation of yaw, pitch and roll, starting from" << endl
-         << "              first image" << endl
-         << "     -m       Optimise photometric parameters" << endl
-         << "     -n       Optimize parameters specified in script file (like PTOptimizer)" << endl
-         << endl
-         << "    Postprocessing options:" << endl
-         << "     -l       level horizon (works best for horizontal panos)" << endl
-         << "     -s       automatically select a suitable output projection and size" << endl
-         << "    Other options:" << endl
-         << "     -q       quiet operation (no progress is reported)" << endl
-         << "     -v HFOV  specify horizontal field of view of input images." << endl
-         << "               Used if the .pto file contains invalid HFOV values" << endl
-         << "               (autopano-SIFT writes .pto files with invalid HFOV)" << endl
-         << endl
-         << "   When using -a -l -m and -s options together, a similar operation to the \"Align\"" << endl
-         << "    button in hugin is performed." << endl
-         << endl;
+         << "     -a       auto align mode, includes various optimisation stages, depending" << std::endl
+         << "               on the amount and distribution of the control points" << std::endl
+         << "     -p       pairwise optimisation of yaw, pitch and roll, starting from" << std::endl
+         << "              first image" << std::endl
+         << "     -m       Optimise photometric parameters" << std::endl
+         << "     -n       Optimize parameters specified in script file (like PTOptimizer)" << std::endl
+         << std::endl
+         << "    Postprocessing options:" << std::endl
+         << "     -l       level horizon (works best for horizontal panos)" << std::endl
+         << "     -s       automatically select a suitable output projection and size" << std::endl
+         << "    Other options:" << std::endl
+         << "     -q       quiet operation (no progress is reported)" << std::endl
+         << "     -v HFOV  specify horizontal field of view of input images." << std::endl
+         << "               Used if the .pto file contains invalid HFOV values" << std::endl
+         << "               (autopano-SIFT writes .pto files with invalid HFOV)" << std::endl
+         << std::endl
+         << "   When using -a -l -m and -s options together, a similar operation to the \"Align\"" << std::endl
+         << "    button in hugin is performed." << std::endl
+         << std::endl;
 }
 
 int main(int argc, char* argv[])
@@ -92,7 +87,7 @@ int main(int argc, char* argv[])
     // parse arguments
     const char* optstring = "alho:npqsv:m";
     int c;
-    string output;
+    std::string output;
     bool doPairwise = false;
     bool doAutoOpt = false;
     bool doNormalOpt = false;
@@ -148,50 +143,50 @@ int main(int argc, char* argv[])
 
     const char* scriptFile = argv[optind];
 
-    Panorama pano;
+    HuginBase::Panorama pano;
     if (scriptFile[0] == '-')
     {
-        DocumentData::ReadWriteError err = pano.readData(std::cin);
-        if (err != DocumentData::SUCCESSFUL)
+        AppBase::DocumentData::ReadWriteError err = pano.readData(std::cin);
+        if (err != AppBase::DocumentData::SUCCESSFUL)
         {
-            cerr << "error while reading script file from stdin." << endl;
-            cerr << "DocumentData::ReadWriteError code: " << err << endl;
+            std::cerr << "error while reading script file from stdin." << std::endl
+                << "DocumentData::ReadWriteError code: " << err << std::endl;
             return 1;
         }
     }
     else
     {
-        ifstream prjfile(scriptFile);
+        std::ifstream prjfile(scriptFile);
         if (!prjfile.good())
         {
-            cerr << "could not open script : " << scriptFile << endl;
+            std::cerr << "could not open script : " << scriptFile << std::endl;
             return 1;
         }
         pano.setFilePrefix(hugin_utils::getPathPrefix(scriptFile));
-        DocumentData::ReadWriteError err = pano.readData(prjfile);
-        if (err != DocumentData::SUCCESSFUL)
+        AppBase::DocumentData::ReadWriteError err = pano.readData(prjfile);
+        if (err != AppBase::DocumentData::SUCCESSFUL)
         {
-            cerr << "error while parsing panos tool script: " << scriptFile << endl;
-            cerr << "DocumentData::ReadWriteError code: " << err << endl;
+            std::cerr << "error while parsing panos tool script: " << scriptFile << std::endl
+                << "DocumentData::ReadWriteError code: " << err << std::endl;
             return 1;
         }
     }
 
     if (pano.getNrOfImages() == 0)
     {
-        cerr << "Panorama should consist of at least one image" << endl;
+        std::cerr << "Panorama should consist of at least one image" << std::endl;
         return 1;
     }
 
     // for bad HFOV (from autopano-SIFT)
     for (unsigned i=0; i < pano.getNrOfImages(); i++)
     {
-        SrcPanoImage img = pano.getSrcImage(i);
-        if (img.getProjection() == SrcPanoImage::RECTILINEAR
+        HuginBase::SrcPanoImage img = pano.getSrcImage(i);
+        if (img.getProjection() == HuginBase::SrcPanoImage::RECTILINEAR
                 && img.getHFOV() >= 180)
         {
             // something is wrong here, try to read from exif data
-            cerr << "HFOV of image " << img.getFilename() << " invalid, trying to read EXIF tags" << endl;
+            std::cerr << "HFOV of image " << img.getFilename() << " invalid, trying to read EXIF tags" << std::endl;
             img.readEXIF();
             bool ok = img.applyEXIFValues(false);
             if (! ok)
@@ -202,7 +197,7 @@ int main(int argc, char* argv[])
                 }
                 else
                 {
-                    cerr << "EXIF reading failed, please specify HFOV with -v" << endl;
+                    std::cerr << "EXIF reading failed, please specify HFOV with -v" << std::endl;
                     return 1;
                 }
             }
@@ -212,75 +207,75 @@ int main(int argc, char* argv[])
 
     if(pano.getNrOfCtrlPoints()==0 && (doPairwise || doAutoOpt || doNormalOpt))
     {
-        cerr << "Panorama have to have control points to optimise positions" << endl;
+        std::cerr << "Panorama have to have control points to optimise positions" << std::endl;
         return 1;
     };
     if (doPairwise && ! doAutoOpt)
     {
         // do pairwise optimisation
-        AutoOptimise::autoOptimise(pano);
+        HuginBase::AutoOptimise::autoOptimise(pano);
 
         // do global optimisation
         if (!quiet)
         {
-            std::cerr << "*** Pairwise position optimisation" << endl;
+            std::cerr << "*** Pairwise position optimisation" << std::endl;
         }
-        PTools::optimize(pano);
+        HuginBase::PTools::optimize(pano);
     }
     else if (doAutoOpt)
     {
         if (!quiet)
         {
-            std::cerr << "*** Adaptive geometric optimisation" << endl;
+            std::cerr << "*** Adaptive geometric optimisation" << std::endl;
         }
-        SmartOptimise::smartOptimize(pano);
+        HuginBase::SmartOptimise::smartOptimize(pano);
     }
     else if (doNormalOpt)
     {
         if (!quiet)
         {
-            std::cerr << "*** Optimising parameters specified in PTO file" << endl;
+            std::cerr << "*** Optimising parameters specified in PTO file" << std::endl;
         }
-        PTools::optimize(pano);
+        HuginBase::PTools::optimize(pano);
     }
     else
     {
         if (!quiet)
         {
-            std::cerr << "*** Geometric parameters not optimized" << endl;
+            std::cerr << "*** Geometric parameters not optimized" << std::endl;
         }
     }
 
     if (doLevel)
     {
         bool hasVerticalLines=false;
-        CPVector allCP=pano.getCtrlPoints();
+        HuginBase::CPVector allCP=pano.getCtrlPoints();
         if(allCP.size()>0 && (doPairwise || doAutoOpt || doNormalOpt))
         {
             for(size_t i=0; i<allCP.size() && !hasVerticalLines; i++)
             {
-                hasVerticalLines=(allCP[i].mode==ControlPoint::X);
+                hasVerticalLines=(allCP[i].mode==HuginBase::ControlPoint::X);
             };
         };
         // straighten only if there are no vertical control points
         if(hasVerticalLines)
         {
-            cout << "Skipping automatic leveling because of existing vertical control points." << endl;
+            std::cout << "Skipping automatic leveling because of existing vertical control points." << std::endl;
         }
         else
         {
-            StraightenPanorama(pano).run();
-            CenterHorizontally(pano).run();
+            HuginBase::StraightenPanorama(pano).run();
+            HuginBase::CenterHorizontally(pano).run();
         };
     }
 
     if (chooseProj)
     {
-        PanoramaOptions opts = pano.getOptions();
-        CalculateFitPanorama fitPano = CalculateFitPanorama(pano);
+        HuginBase::PanoramaOptions opts = pano.getOptions();
+        HuginBase::CalculateFitPanorama fitPano(pano);
         fitPano.run();
         opts.setHFOV(fitPano.getResultHorizontalFOV());
-        opts.setHeight(roundi(fitPano.getResultHeight()));
+        opts.setHeight(hugin_utils::roundi(fitPano.getResultHeight()));
         const double vfov = opts.getVFOV();
         const double hfov = opts.getHFOV();
         // avoid perspective projection if field of view > 100 deg
@@ -291,17 +286,17 @@ int main(int argc, char* argv[])
             // cylindrical or rectilinear
             if (hfov < mf)
             {
-                if (opts.getProjection() != PanoramaOptions::RECTILINEAR)
+                if (opts.getProjection() != HuginBase::PanoramaOptions::RECTILINEAR)
                 {
-                    opts.setProjection(PanoramaOptions::RECTILINEAR);
+                    opts.setProjection(HuginBase::PanoramaOptions::RECTILINEAR);
                     changedProjection = true;
                 };
             }
             else
             {
-                if (opts.getProjection() != PanoramaOptions::CYLINDRICAL)
+                if (opts.getProjection() != HuginBase::PanoramaOptions::CYLINDRICAL)
                 {
-                    opts.setProjection(PanoramaOptions::CYLINDRICAL);
+                    opts.setProjection(HuginBase::PanoramaOptions::CYLINDRICAL);
                     changedProjection = true;
                 };
             }
@@ -310,56 +305,54 @@ int main(int argc, char* argv[])
         // the projection could be changed, calculate fit again
         if(changedProjection)
         {
-            CalculateFitPanorama fitPano2 = CalculateFitPanorama(pano);
+            HuginBase::CalculateFitPanorama fitPano2(pano);
             fitPano2.run();
             opts.setHFOV(fitPano2.getResultHorizontalFOV());
-            opts.setHeight(roundi(fitPano2.getResultHeight()));
+            opts.setHeight(hugin_utils::roundi(fitPano2.getResultHeight()));
             pano.setOptions(opts);
         };
 
         // downscale pano a little
         const double sizeFactor = 0.7;
-        const double w = CalculateOptimalScale::calcOptimalScale(pano);
-        opts.setWidth(roundi(opts.getWidth()*w*sizeFactor), true);
+        const double w = HuginBase::CalculateOptimalScale::calcOptimalScale(pano);
+        opts.setWidth(hugin_utils::roundi(opts.getWidth()*w*sizeFactor), true);
         pano.setOptions(opts);
     }
 
     if(doPhotometric)
     {
         // photometric estimation
-        PanoramaOptions opts = pano.getOptions();
+        HuginBase::PanoramaOptions opts = pano.getOptions();
         int nPoints = 200;
-        int pyrLevel=3;
-        bool randomPoints = true;
         nPoints = nPoints * pano.getNrOfImages();
 
         std::vector<vigra_ext::PointPairRGB> points;
-        ProgressDisplay* progressDisplay;
+        AppBase::ProgressDisplay* progressDisplay;
         if(!quiet)
         {
-            progressDisplay=new StreamProgressDisplay(std::cout);
+            progressDisplay=new AppBase::StreamProgressDisplay(std::cout);
         }
         else
         {
-            progressDisplay=new DummyProgressDisplay();
+            progressDisplay=new AppBase::DummyProgressDisplay();
         }
         try
         {
-            loadImgsAndExtractPoints(pano, nPoints, pyrLevel, randomPoints, *progressDisplay, points, !quiet);
+            loadImgsAndExtractPoints(pano, nPoints, 3, true, *progressDisplay, points, !quiet);
         }
         catch (std::exception& e)
         {
-            cerr << "caught exception: " << e.what() << endl;
+            std::cerr << "caught exception: " << e.what() << std::endl;
             return 1;
         };
         if(!quiet)
         {
-            cout << "\rSelected " << points.size() << " points" << endl;
+            std::cout << "\rSelected " << points.size() << " points" << std::endl;
         }
 
         if (points.size() == 0)
         {
-            cerr << "Error: no overlapping points found, exiting" << endl;
+            std::cerr << "Error: no overlapping points found, exiting" << std::endl;
             return 1;
         }
 
@@ -398,32 +391,32 @@ int main(int argc, char* argv[])
 
         HuginBase::SmartPhotometricOptimizer::PhotometricOptimizeMode optmode =
             HuginBase::SmartPhotometricOptimizer::OPT_PHOTOMETRIC_LDR_WB;
-        if (opts.outputMode == PanoramaOptions::OUTPUT_HDR)
+        if (opts.outputMode == HuginBase::PanoramaOptions::OUTPUT_HDR)
         {
             optmode = HuginBase::SmartPhotometricOptimizer::OPT_PHOTOMETRIC_HDR;
         }
-        SmartPhotometricOptimizer photoOpt(pano, progressDisplay, pano.getOptimizeVector(), points, optmode);
+        HuginBase::SmartPhotometricOptimizer photoOpt(pano, progressDisplay, pano.getOptimizeVector(), points, optmode);
         photoOpt.run();
 
         // calculate the mean exposure.
-        opts.outputExposureValue = CalculateMeanExposure::calcMeanExposure(pano);
+        opts.outputExposureValue = HuginBase::CalculateMeanExposure::calcMeanExposure(pano);
         pano.setOptions(opts);
         progressDisplay->taskFinished();
         delete progressDisplay;
     };
 
     // write result
-    OptimizeVector optvec = pano.getOptimizeVector();
-    UIntSet imgs;
+    HuginBase::OptimizeVector optvec = pano.getOptimizeVector();
+    HuginBase::UIntSet imgs;
     fill_set(imgs,0, pano.getNrOfImages()-1);
     if (output != "")
     {
-        ofstream of(output.c_str());
+        std::ofstream of(output.c_str());
         pano.printPanoramaScript(of, optvec, pano.getOptions(), imgs, false, hugin_utils::getPathPrefix(scriptFile));
     }
     else
     {
-        pano.printPanoramaScript(cout, optvec, pano.getOptions(), imgs, false, hugin_utils::getPathPrefix(scriptFile));
+        pano.printPanoramaScript(std::cout, optvec, pano.getOptions(), imgs, false, hugin_utils::getPathPrefix(scriptFile));
     }
     return 0;
 }
