@@ -30,44 +30,39 @@
 
 #include <fstream>
 #include <sstream>
-#ifdef WIN32
 #include <getopt.h>
-#else
-#include <unistd.h>
-#endif
 
 #include <algorithms/optimizer/PTOptimizer.h>
+#include <algorithms/optimizer/ImageGraph.h>
 #include <algorithms/control_points/CleanCP.h>
 #include "panotools/PanoToolsInterface.h"
 
-using namespace std;
-using namespace HuginBase;
-using namespace AppBase;
-
 static void usage(const char* name)
 {
-    cout << name << ": remove wrong control points by statistic method" << endl
-         << "cpclean version " << hugin_utils::GetHuginVersion() << endl
-         << endl
-         << "Usage:  " << name << " [options] input.pto" << endl
-         << endl
-         << "CPClean uses statistical methods to remove wrong control points" << endl << endl
-         << "Step 1 optimises all images pairs, calculates for each pair mean " << endl
-         << "       and standard deviation and removes all control points " << endl
-         << "       with error bigger than mean+n*sigma" << endl
-         << "Step 2 optimises the whole panorama, calculates mean and standard deviation" << endl
-         << "       for all control points and removes all control points with error" << endl
-         << "       bigger than mean+n*sigma" << endl << endl
-         << "  Options:" << endl
-         << "     -o file.pto  Output Hugin PTO file. Default: '<filename>_clean.pto'." << endl
-         << "     -n num   distance factor for checking (default: 2)" << endl
-         << "     -p       do only pairwise optimisation (skip step 2)" << endl
-         << "     -w       do optimise whole panorama (skip step 1)" << endl
-         << "     -s       skip optimisation step when optimisation the whole panorama" << endl
-         << "     -l       also include line control points for calculation and" << endl
-         << "              filtering in step 2" << endl
-         << "     -h       shows help" << endl
-         << endl;
+    std::cout << name << ": remove wrong control points by statistic method" << std::endl
+        << "cpclean version " << hugin_utils::GetHuginVersion() << std::endl
+        << std::endl
+        << "Usage:  " << name << " [options] input.pto" << std::endl
+        << std::endl
+        << "CPClean uses statistical methods to remove wrong control points" << std::endl << std::endl
+        << "Step 1 optimises all images pairs, calculates for each pair mean " << std::endl
+        << "       and standard deviation and removes all control points " << std::endl
+        << "       with error bigger than mean+n*sigma" << std::endl
+        << "Step 2 optimises the whole panorama, calculates mean and standard deviation" << std::endl
+        << "       for all control points and removes all control points with error" << std::endl
+        << "       bigger than mean+n*sigma" << std::endl << std::endl
+        << "  Options:" << std::endl
+        << "     --output|-o file.pto     Output Hugin PTO file." << std::endl
+        << "                              Default: '<filename>_clean.pto'." << std::endl
+        << "     --max-distance|-n num    distance factor for checking (default: 2)" << std::endl
+        << "     --pairwise-checking|-p   do only pairwise optimisation (skip step 2)" << std::endl
+        << "     --whole-pano-checking|-w do optimise whole panorama (skip step 1)" << std::endl
+        << "     --dont-optimize|-s       skip optimisation step when optimisation the" << std::endl
+        << "                              whole panorama" << std::endl
+        << "     --check-line-cp|-l       also include line control points for calculation" << std::endl
+        << "                              and filtering in step 2" << std::endl
+        << "     --help|-h                 shows help" << std::endl
+        << std::endl;
 }
 
 // dummy panotools progress functions
@@ -85,16 +80,27 @@ int main(int argc, char* argv[])
 {
     // parse arguments
     const char* optstring = "o:hn:pwslv";
-
+    static struct option longOptions[] =
+    {
+        { "output", required_argument, NULL, 'o'},
+        { "max-distance", required_argument, NULL, 'n'},
+        { "pairwise-checking", no_argument, NULL, 'p'},
+        { "whole-pano-checking", no_argument, NULL, 'w'},
+        { "dont-optimize", no_argument, NULL, 's'},
+        { "check-line-cp", no_argument, NULL, 'l' },
+        { "help", no_argument, NULL, 'h' },
+        0
+    };
     int c;
-    string output;
+    std::string output;
     bool onlyPair = false;
     bool wholePano = false;
     bool skipOptimisation = false;
     bool includeLineCp = false;
     bool verbose = false;
     double n = 2.0;
-    while ((c = getopt (argc, argv, optstring)) != -1)
+    int optionIndex = 0;
+    while ((c = getopt_long(argc, argv, optstring, longOptions, &optionIndex)) != -1)
     {
         switch (c)
         {
@@ -108,12 +114,12 @@ int main(int argc, char* argv[])
                 n = atof(optarg);
                 if(n==0)
                 {
-                    cerr <<"Invalid parameter: " << optarg << " is not valid real number" << endl;
+                    std::cerr <<"Invalid parameter: " << optarg << " is not valid real number" << std::endl;
                     return 1;
                 };
                 if (n<1.0)
                 {
-                    cerr << "Invalid parameter: n must be at least 1" << endl;
+                    std::cerr << "Invalid parameter: n must be at least 1" << std::endl;
                     return 1;
                 };
                 break;
@@ -133,7 +139,7 @@ int main(int argc, char* argv[])
                 verbose = true;
                 break;
             case ':':
-                cerr <<"Option -n requires a number" << endl;
+                std::cerr <<"Option -n requires a number" << std::endl;
                 return 1;
                 break;
             case '?':
@@ -151,38 +157,38 @@ int main(int argc, char* argv[])
 
     if (onlyPair && wholePano)
     {
-        cerr << "Options -p and -w can't used together" << endl;
+        std::cerr << "Options -p and -w can't used together" << std::endl;
         return 1;
     };
 
-    string input=argv[optind];
+    std::string input=argv[optind];
 
-    Panorama pano;
-    ifstream prjfile(input.c_str());
+    HuginBase::Panorama pano;
+    std::ifstream prjfile(input.c_str());
     if (!prjfile.good())
     {
-        cerr << "could not open script : " << input << endl;
+        std::cerr << "could not open script : " << input << std::endl;
         return 1;
     }
     pano.setFilePrefix(hugin_utils::getPathPrefix(input));
-    DocumentData::ReadWriteError err = pano.readData(prjfile);
-    if (err != DocumentData::SUCCESSFUL)
+    AppBase::DocumentData::ReadWriteError err = pano.readData(prjfile);
+    if (err != AppBase::DocumentData::SUCCESSFUL)
     {
-        cerr << "error while parsing panos tool script: " << input << endl;
-        cerr << "DocumentData::ReadWriteError code: " << err << endl;
+        std::cerr << "error while parsing panos tool script: " << input << std::endl;
+        std::cerr << "DocumentData::ReadWriteError code: " << err << std::endl;
         return 1;
     }
 
-    size_t nrImg=pano.getNrOfImages();
+    const size_t nrImg=pano.getNrOfImages();
     if (nrImg < 2)
     {
-        cerr << "Panorama should consist of at least two images" << endl;
+        std::cerr << "Panorama should consist of at least two images" << std::endl;
         return 1;
     }
 
     if (pano.getNrOfCtrlPoints() < 3)
     {
-        cerr << "Panorama should contain at least 3 control point" << endl;
+        std::cerr << "Panorama should contain at least 3 control point" << std::endl;
     };
 
     if (!verbose)
@@ -191,15 +197,15 @@ int main(int argc, char* argv[])
         PT_setInfoDlgFcn(ptinfoDlg);
     };
 
-    size_t cpremoved1=0;
-    UIntSet CPtoRemove;
+    size_t cpremoved1 = 0;
+    HuginBase::UIntSet CPtoRemove;
     // step 1 with pairwise optimisation
     if(!wholePano)
     {
         AppBase::DummyProgressDisplay dummy;
         CPtoRemove=getCPoutsideLimit_pair(pano, dummy, n);
         if (CPtoRemove.size()>0)
-            for(UIntSet::reverse_iterator it = CPtoRemove.rbegin(); it != CPtoRemove.rend(); ++it)
+            for (HuginBase::UIntSet::reverse_iterator it = CPtoRemove.rbegin(); it != CPtoRemove.rend(); ++it)
             {
                 pano.removeCtrlPoint(*it);
             }
@@ -211,57 +217,53 @@ int main(int argc, char* argv[])
     if(!onlyPair)
     {
         //check for unconnected images
-        CPGraph graph;
-        createCPGraph(pano, graph);
-        CPComponents comps;
-        int parts=findCPComponents(graph, comps);
-        if (parts > 1)
-        {
-            unconnected=true;
-        }
-        else
+        HuginGraph::ImageGraph graph(pano);
+        unconnected = !graph.IsConnected();
+        if (!unconnected)
         {
             CPtoRemove.clear();
             if(skipOptimisation)
             {
-                std::cout << endl << "Skipping optimisation, current image positions will be used." << endl;
+                std::cout << std::endl << "Skipping optimisation, current image positions will be used." << std::endl;
             };
             CPtoRemove=getCPoutsideLimit(pano, n, skipOptimisation, includeLineCp);
             if (CPtoRemove.size()>0)
-                for(UIntSet::reverse_iterator it = CPtoRemove.rbegin(); it != CPtoRemove.rend(); ++it)
+                for (HuginBase::UIntSet::reverse_iterator it = CPtoRemove.rbegin(); it != CPtoRemove.rend(); ++it)
                 {
                     pano.removeCtrlPoint(*it);
                 }
         };
     };
 
-    cout << endl;
+    std::cout << std::endl;
     if(!wholePano)
     {
-        cout << "Removed " << cpremoved1 << " control points in step 1" << endl;
+        std::cout << "Removed " << cpremoved1 << " control points in step 1" << std::endl;
     }
-    if(!onlyPair)
-        if(unconnected)
+    if (!onlyPair)
+    {
+        if (unconnected)
         {
-            cout <<"Skipped step 2 because of unconnected image pairs" << endl;
+            std::cout << "Skipped step 2 because of unconnected image pairs" << std::endl;
         }
         else
         {
-            cout << "Removed " << CPtoRemove.size() << " control points in step 2" << endl;
-        }
+            std::cout << "Removed " << CPtoRemove.size() << " control points in step 2" << std::endl;
+        };
+    };
 
     //write output
-    OptimizeVector optvec = pano.getOptimizeVector();
-    UIntSet imgs;
+    HuginBase::OptimizeVector optvec = pano.getOptimizeVector();
+    HuginBase::UIntSet imgs;
     fill_set(imgs,0, pano.getNrOfImages()-1);
     // Set output .pto filename if not given
     if (output=="")
     {
         output=input.substr(0,input.length()-4).append("_clean.pto");
     }
-    ofstream of(output.c_str());
+    std::ofstream of(output.c_str());
     pano.printPanoramaScript(of, optvec, pano.getOptions(), imgs, false, hugin_utils::getPathPrefix(input));
 
-    cout << endl << "Written output to " << output << endl;
+    std::cout << std::endl << "Written output to " << output << std::endl;
     return 0;
 }
